@@ -47,31 +47,9 @@ QCString getResourcePath()
   return result;
 }
 
-#define GRAPHVIZ_PATH    "/Applications/Graphviz.app"
-#define DOT_PATH         GRAPHVIZ_PATH "/Contents/MacOS"
-#define DOT_LOCATION     DOT_PATH "/dot"
-
-bool checkIfDotInstalled()
-{
-  QFileInfo fi(GRAPHVIZ_PATH);
-  if (fi.exists() && fi.isDir())
-  {
-    fi.setFile(DOT_LOCATION);
-    if (fi.exists() && fi.isFile())
-    {
-      return TRUE;
-    }
-  }
-  return FALSE;
-}
-
 void setDotPath()
 {
-  if (checkIfDotInstalled())
-  {
-    Config_getString("DOT_PATH")=DOT_PATH;
-    Config_getBool("HAVE_DOT")=TRUE;
-  }
+  Config_getString("DOT_PATH")=getResourcePath();
 }
 
 #endif
@@ -228,11 +206,12 @@ Step2::Step2(QWidget *parent) : QWidget(parent,"Step2")
   layout->addWidget(f);
 
   m_optimizeLang = new QButtonGroup("Select programming language to optimize the results for",this);
-  gbox = new QGridLayout( m_optimizeLang, 4, 1, 8, 0 );
+  gbox = new QGridLayout( m_optimizeLang, 5, 1, 8, 0 );
   gbox->addRowSpacing( 0, fontMetrics().lineSpacing()+2 );
   gbox->addWidget(new QRadioButton("Optimize for C++ output",m_optimizeLang),1,0);
   gbox->addWidget(new QRadioButton("Optimize for Java output",m_optimizeLang),2,0);
   gbox->addWidget(new QRadioButton("Optimize for C output",m_optimizeLang),3,0);
+  gbox->addWidget(new QRadioButton("Optimize for C# output",m_optimizeLang),4,0);
   m_optimizeLang->setButton(0);
   layout->addWidget(m_optimizeLang);
 
@@ -272,6 +251,7 @@ OptLang Step2::optimizeFor() const
     case 0:  return Lang_Cpp;
     case 1:  return Lang_Java;
     case 2:  return Lang_C;
+    case 3:  return Lang_CS;
   }
   return Lang_Cpp;
 }
@@ -295,6 +275,7 @@ void Step2::setOptimizeFor(OptLang lang)
     case Lang_Cpp:  m_optimizeLang->setButton(0); break;
     case Lang_Java: m_optimizeLang->setButton(1); break;
     case Lang_C:    m_optimizeLang->setButton(2); break;
+    case Lang_CS:   m_optimizeLang->setButton(3); break;
   }
 }
 
@@ -512,7 +493,12 @@ Step4::Step4(QWidget *parent) : QWidget(parent,"Step4")
     dotGroup->setButton(0);
     m_dotOptions->setEnabled(FALSE);
   gbox->addWidget(w,4,0);
+
+#if defined(Q_OS_MACX) // we bundle dot with the mac package
+  m_diagramMode->setButton(2);
+#else
   m_diagramMode->setButton(1);
+#endif
   layout->addWidget(m_diagramMode);
   layout->addStretch(1);
 
@@ -678,6 +664,7 @@ MainWidget::MainWidget(QWidget *parent)
   // initialize config settings
   Config::instance()->init();
   Config::instance()->check();
+  Config_getBool("HAVE_DOT")=TRUE;
 #if defined(Q_OS_MACX)
   setDotPath();
 #endif
@@ -887,8 +874,8 @@ void MainWidget::launchWizard()
   // --------  Initialize the dialog ----------------
   
   // step1
-  wizard.setProjectName(Config_getString("PROJECT_NAME"));
-  wizard.setProjectNumber(Config_getString("PROJECT_NUMBER"));
+  wizard.setProjectName(QString::fromLocal8Bit(Config_getString("PROJECT_NAME")));
+  wizard.setProjectNumber(QString::fromLocal8Bit(Config_getString("PROJECT_NUMBER")));
   if (Config_getList("INPUT").count()>0)
   {
     QString dirName=Config_getList("INPUT").getFirst();
@@ -899,7 +886,7 @@ void MainWidget::launchWizard()
     }
   }
   wizard.setRecursiveScan(Config_getBool("RECURSIVE"));
-  wizard.setDestinationDir(Config_getString("OUTPUT_DIRECTORY"));
+  wizard.setDestinationDir(QString::fromLocal8Bit(Config_getString("OUTPUT_DIRECTORY")));
 
   // step2
   wizard.setExtractAll(Config_getBool("EXTRACT_ALL"));
@@ -979,12 +966,12 @@ void MainWidget::launchWizard()
     // -------- Store the results ----------------
 
     // step1
-    Config_getString("PROJECT_NAME")=wizard.getProjectName();
+    Config_getString("PROJECT_NAME")=wizard.getProjectName().local8Bit();
     Config_getString("PROJECT_NUMBER")=wizard.getProjectNumber();
     Config_getList("INPUT").clear();
     Config_getList("INPUT").append(wizard.getSourceDir());
     Config_getBool("RECURSIVE")=wizard.scanRecursively();
-    Config_getString("OUTPUT_DIRECTORY")=wizard.getDestinationDir();
+    Config_getString("OUTPUT_DIRECTORY")=wizard.getDestinationDir().local8Bit();
 
     // step2
     if (wizard.extractAll())
@@ -1035,6 +1022,12 @@ void MainWidget::launchWizard()
         Config_getBool("OPTIMIZE_OUTPUT_FOR_C")=TRUE;
         Config_getBool("OPTIMIZE_OUTPUT_JAVA")=FALSE;
         break;
+      case Lang_CS:
+        Config_getBool("OPTIMIZE_OUTPUT_FOR_C")=FALSE;
+        Config_getBool("OPTIMIZE_OUTPUT_JAVA")=TRUE;
+        Config_getBool("EXTRACT_STATIC")=TRUE;
+        Config_getBool("EXTRACT_LOCAL_CLASSES")=TRUE;
+        break;
     }
 
     // step3
@@ -1125,7 +1118,7 @@ void MainWidget::loadConfigFromFile(const QString &fn)
   else
   {
     Config::instance()->convertStrToVal();
-#if defined(Q_OS_MACX)
+#if 0 //defined(Q_OS_MACX)
     if (checkIfDotInstalled() && 
         qstricmp(Config_getString("DOT_PATH"),DOT_PATH)!=0
        )
@@ -1163,9 +1156,9 @@ void MainWidget::launchExpert()
   Expert expert(this);
   expert.init();
   expert.exec();
-#if defined(Q_OS_MACX)
-  setDotPath();
-#endif
+//#if defined(Q_OS_MACX)
+//  setDotPath();
+//#endif
   if (expert.hasChanged()) setConfigSaved(FALSE);
 }
 
@@ -1323,7 +1316,7 @@ void MainWidget::about()
   QTextStream t(&msg,IO_WriteOnly);
   t << QString("<qt><center>A tool to configure and run doxygen version ")+versionString+
        " on your source files.</center><p><br>"
-       "<center>Written by<br> Dimitri van Heesch<br>&copy; 2000-2005</center><p>"
+       "<center>Written by<br> Dimitri van Heesch<br>&copy; 2000-2006</center><p>"
        "</qt>";
   QMessageBox::about(this,"Doxygen GUI",msg);
 }
