@@ -3,7 +3,7 @@
  * 
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -132,8 +132,8 @@ CommandMap htmlTagMap[] =
   { "ol",         HTML_OL },
   { "ul",         HTML_UL },
   { "li",         HTML_LI },
-  { "tt",         HTML_CODE },
-  { "kbd",        HTML_CODE },
+  { "tt",         XML_C /*HTML_CODE*/ },
+  { "kbd",        XML_C /*HTML_CODE*/ },
   { "em",         HTML_EMPHASIS },
   { "hr",         HTML_HR },
   { "dl",         HTML_DL },
