@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: code.h,v 1.9 2001/03/19 19:27:39 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,13 +21,15 @@
 #include "qtbc.h"
 #include <stdio.h>
 
-class BaseCodeDocInterface;
+class CodeOutputInterface;
 class FileDef;
 class MemberDef;
 
-extern void parseCode(BaseCodeDocInterface &,const char *,const QCString &, 
+void parseCCode(CodeOutputInterface &,const char *,const QCString &, 
             bool ,const char *,FileDef *fd=0,
-            int startLine=-1,int endLine=-1,bool inlineFragment=FALSE);
-extern void initParseCodeContext();
-extern void setParameterList(MemberDef *md);
+            int startLine=-1,int endLine=-1,bool inlineFragment=FALSE,
+            MemberDef *memberDef=0);
+void resetCCodeParserState();
+void codeFreeScanner();
+
 #endif
