@@ -137,7 +137,7 @@ void generateDEFForMember(MemberDef *md,
   if (isFunc) //function
   {
     ArgumentList *declAl = new ArgumentList;
-    ArgumentList *defAl = md->argumentList();
+    LockingPtr<ArgumentList> defAl = md->argumentList();
     stringToArgumentList(md->argsString(),declAl);
     QCString fcnPrefix = "  " + memPrefix + "param-";
 
@@ -213,9 +213,10 @@ void generateDEFForMember(MemberDef *md,
   // TODO: exceptions, const volatile
   if (md->memberType()==MemberDef::Enumeration) // enum
   {
-    if (md->enumFieldList())
+    LockingPtr<MemberList> enumList = md->enumFieldList();
+    if (enumList!=0)
     {
-      MemberListIterator emli(*md->enumFieldList());
+      MemberListIterator emli(*enumList);
       MemberDef *emd;
       for (emli.toFirst();(emd=emli.current());++emli)
       {
@@ -239,9 +240,11 @@ void generateDEFForMember(MemberDef *md,
     << md->documentation() << endl << "_EnD_oF_dEf_TeXt_;" << endl;
 
   //printf("md->getReferencesMembers()=%p\n",md->getReferencesMembers());
-  if (md->getReferencesMembers())
+
+  LockingPtr<MemberSDict> mdict = md->getReferencesMembers();
+  if (!mdict.isNull())
   {
-    MemberSDict::Iterator mdi(*md->getReferencesMembers());
+    MemberSDict::Iterator mdi(*mdict);
     MemberDef *rmd;
     QCString refPrefix = "  " + memPrefix + "ref-";
 
@@ -271,9 +274,10 @@ void generateDEFForMember(MemberDef *md,
       }
     } /* for (mdi.toFirst...) */
   }
-  if (md->getReferencedByMembers())
+  mdict = md->getReferencedByMembers();
+  if (!mdict.isNull())
   {
-    MemberSDict::Iterator mdi(*md->getReferencedByMembers());
+    MemberSDict::Iterator mdi(*mdict);
     MemberDef *rmd;
     QCString refPrefix = "  " + memPrefix + "ref-";
 
@@ -313,7 +317,7 @@ void generateDEFClassSection(ClassDef *cd,
     MemberList *ml,
     const char *kind)
 {
-  if (ml->count()>0)
+  if (cd && ml && ml->count()>0)
   {
     t << "  cp-section = {" << endl;
     t << "    sec-kind = '" << kind << "';" << endl;
@@ -352,7 +356,7 @@ void generateDEFForClass(ClassDef *cd,QTextStream &t)
   t << "  cp-id     = '" << cd->getOutputFileBase() << "';" << endl;
   t << "  cp-name   = '" << cd->name() << "';" << endl;
 
-  if (cd->baseClasses()->count()>0)
+  if (cd->baseClasses())
   {
     BaseClassListIterator bcli(*cd->baseClasses());
     BaseClassDef *bcd;
@@ -380,7 +384,7 @@ void generateDEFForClass(ClassDef *cd,QTextStream &t)
     }
   }
 
-  if (cd->subClasses()->count()>0)
+  if (cd->subClasses())
   {
     BaseClassListIterator bcli(*cd->subClasses());
     BaseClassDef *bcd;
@@ -408,40 +412,41 @@ void generateDEFForClass(ClassDef *cd,QTextStream &t)
     }
   }
 
-  int numMembers = 
-    cd->pubTypes.count()+cd->pubMethods.count()+cd->pubAttribs.count()+
-    cd->pubSlots.count()+cd->signals.count()+cd->dcopMethods.count()+
-    cd->pubStaticMethods.count()+
-    cd->pubStaticAttribs.count()+cd->proTypes.count()+cd->proMethods.count()+
-    cd->proAttribs.count()+cd->proSlots.count()+cd->proStaticMethods.count()+
-    cd->proStaticAttribs.count()+cd->priTypes.count()+cd->priMethods.count()+
-    cd->priAttribs.count()+cd->priSlots.count()+cd->priStaticMethods.count()+
-    cd->priStaticAttribs.count()+cd->friends.count()+cd->related.count();
+  int numMembers = 0;
+  QListIterator<MemberList> mli(cd->getMemberLists());
+  MemberList *ml;
+  for (mli.toFirst();(ml=mli.current());++mli)
+  {
+    if ((ml->listType()&MemberList::detailedLists)==0)
+    {
+      numMembers+=ml->count();
+    }
+  }
   if (numMembers>0)
   {
-    generateDEFClassSection(cd,t,&cd->pubTypes,"public-type");
-    generateDEFClassSection(cd,t,&cd->pubMethods,"public-func");
-    generateDEFClassSection(cd,t,&cd->pubAttribs,"public-attrib");
-    generateDEFClassSection(cd,t,&cd->pubSlots,"public-slot");
-    generateDEFClassSection(cd,t,&cd->signals,"signal");
-    generateDEFClassSection(cd,t,&cd->dcopMethods,"dcop-func");
-    generateDEFClassSection(cd,t,&cd->properties,"property");
-    generateDEFClassSection(cd,t,&cd->pubStaticMethods,"public-static-func");
-    generateDEFClassSection(cd,t,&cd->pubStaticAttribs,"public-static-attrib");
-    generateDEFClassSection(cd,t,&cd->proTypes,"protected-type");
-    generateDEFClassSection(cd,t,&cd->proMethods,"protected-func");
-    generateDEFClassSection(cd,t,&cd->proAttribs,"protected-attrib");
-    generateDEFClassSection(cd,t,&cd->proSlots,"protected-slot");
-    generateDEFClassSection(cd,t,&cd->proStaticMethods,"protected-static-func");
-    generateDEFClassSection(cd,t,&cd->proStaticAttribs,"protected-static-attrib");
-    generateDEFClassSection(cd,t,&cd->priTypes,"private-type");
-    generateDEFClassSection(cd,t,&cd->priMethods,"private-func");
-    generateDEFClassSection(cd,t,&cd->priAttribs,"private-attrib");
-    generateDEFClassSection(cd,t,&cd->priSlots,"private-slot");
-    generateDEFClassSection(cd,t,&cd->priStaticMethods,"private-static-func");
-    generateDEFClassSection(cd,t,&cd->priStaticAttribs,"private-static-attrib");
-    generateDEFClassSection(cd,t,&cd->friends,"signal");
-    generateDEFClassSection(cd,t,&cd->related,"related");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::pubTypes),"public-type");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::pubMethods),"public-func");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::pubAttribs),"public-attrib");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::pubSlots),"public-slot");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::signals),"signal");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::dcopMethods),"dcop-func");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::properties),"property");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::pubStaticMethods),"public-static-func");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::pubStaticAttribs),"public-static-attrib");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::proTypes),"protected-type");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::proMethods),"protected-func");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::proAttribs),"protected-attrib");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::proSlots),"protected-slot");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::proStaticMethods),"protected-static-func");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::proStaticAttribs),"protected-static-attrib");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::priTypes),"private-type");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::priMethods),"private-func");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::priAttribs),"private-attrib");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::priSlots),"private-slot");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::priStaticMethods),"private-static-func");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::priStaticAttribs),"private-static-attrib");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::friends),"signal");
+    generateDEFClassSection(cd,t,cd->getMemberList(MemberList::related),"related");
   }
 
   t << "  cp-filename  = '" << cd->getDefFileName() << "';" << endl;
@@ -498,12 +503,12 @@ void generateDEFForNamespace(NamespaceDef *nd,QTextStream &t)
   writeDEFString(t,nd->name());
   t << ';' << endl;
 
-  generateDEFSection(nd,t,&nd->decDefineMembers,"define");
-  generateDEFSection(nd,t,&nd->decProtoMembers,"prototype");
-  generateDEFSection(nd,t,&nd->decTypedefMembers,"typedef");
-  generateDEFSection(nd,t,&nd->decEnumMembers,"enum");
-  generateDEFSection(nd,t,&nd->decFuncMembers,"func");
-  generateDEFSection(nd,t,&nd->decVarMembers,"var");
+  generateDEFSection(nd,t,nd->getMemberList(MemberList::decDefineMembers),"define");
+  generateDEFSection(nd,t,nd->getMemberList(MemberList::decProtoMembers),"prototype");
+  generateDEFSection(nd,t,nd->getMemberList(MemberList::decTypedefMembers),"typedef");
+  generateDEFSection(nd,t,nd->getMemberList(MemberList::decEnumMembers),"enum");
+  generateDEFSection(nd,t,nd->getMemberList(MemberList::decFuncMembers),"func");
+  generateDEFSection(nd,t,nd->getMemberList(MemberList::decVarMembers),"var");
 
   t << "  ns-filename  = '" << nd->getDefFileName() << "';" << endl;
   t << "  ns-fileline  = '" << nd->getDefLine()     << "';" << endl;
@@ -525,12 +530,12 @@ void generateDEFForFile(FileDef *fd,QTextStream &t)
   writeDEFString(t,fd->name());
   t << ';' << endl;
 
-  generateDEFSection(fd,t,&fd->decDefineMembers,"define");
-  generateDEFSection(fd,t,&fd->decProtoMembers,"prototype");
-  generateDEFSection(fd,t,&fd->decTypedefMembers,"typedef");
-  generateDEFSection(fd,t,&fd->decEnumMembers,"enum");
-  generateDEFSection(fd,t,&fd->decFuncMembers,"func");
-  generateDEFSection(fd,t,&fd->decVarMembers,"var");
+  generateDEFSection(fd,t,fd->getMemberList(MemberList::decDefineMembers),"define");
+  generateDEFSection(fd,t,fd->getMemberList(MemberList::decProtoMembers),"prototype");
+  generateDEFSection(fd,t,fd->getMemberList(MemberList::decTypedefMembers),"typedef");
+  generateDEFSection(fd,t,fd->getMemberList(MemberList::decEnumMembers),"enum");
+  generateDEFSection(fd,t,fd->getMemberList(MemberList::decFuncMembers),"func");
+  generateDEFSection(fd,t,fd->getMemberList(MemberList::decVarMembers),"var");
 
   t << "  file-full-name  = '" << fd->getDefFileName() << "';" << endl;
   t << "  file-first-line = '" << fd->getDefLine()     << "';" << endl;
@@ -601,15 +606,15 @@ void generateDEF()
   QTextStream t(&f);
   t << "AutoGen Definitions dummy;" << endl;
 
-  if (Doxygen::classSDict.count()+Doxygen::inputNameList.count()>0)
+  if (Doxygen::classSDict->count()+Doxygen::inputNameList->count()>0)
   {
-    ClassSDict::Iterator cli(Doxygen::classSDict);
+    ClassSDict::Iterator cli(*Doxygen::classSDict);
     ClassDef *cd;
     for (cli.toFirst();(cd=cli.current());++cli)
     {
       generateDEFForClass(cd,t);
     }
-    FileNameListIterator fnli(Doxygen::inputNameList);
+    FileNameListIterator fnli(*Doxygen::inputNameList);
     FileName *fn;
     for (;(fn=fnli.current());++fnli)
     {
