@@ -20,6 +20,7 @@
 #include <qregexp.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <assert.h>
 #include "config.h"
 #include "definition.h"
 #include "doxygen.h"
@@ -33,32 +34,173 @@
 #include "section.h"
 #include "htags.h"
 #include "parserintf.h"
+#include "marshal.h"
 
 #if defined(_MSC_VER) || defined(__BORLANDC__)
 #define popen _popen
 #define pclose _pclose
 #endif
 
-static void addToMap(const char *name,Definition *d)
+#define START_MARKER 0x4445465B // DEF[
+#define END_MARKER   0x4445465D // DEF]
+
+
+class DefinitionImpl
+{
+  public:
+    DefinitionImpl();
+   ~DefinitionImpl();
+    void init(const char *df,int dl,
+         const char *n,const char *b,
+         const char *d);
+
+    SectionDict *sectionDict;  // dictionary of all sections, not accessible
+
+    MemberSDict *sourceRefByDict;       
+    MemberSDict *sourceRefsDict;        
+    QList<ListItemInfo> *xrefListItems; 
+    GroupList *partOfGroups;            
+
+    DocInfo  *details; // not exported
+    DocInfo  *brief;   // not exported
+    BodyInfo *body;    // not exported
+
+    QCString localName;      // local (unqualified) name of the definition
+                               // in the future m_name should become m_localName
+    QCString qualifiedName;
+    QCString ref;   // reference to external documentation
+
+    bool hidden;
+
+    Definition *outerScope;  // not owner
+
+    // where the item was found
+    QCString defFileName;
+    int      defLine;
+    QCString defFileExt;
+};
+
+DefinitionImpl::DefinitionImpl() 
+  : sectionDict(0), sourceRefByDict(0), sourceRefsDict(0), 
+    xrefListItems(0), partOfGroups(0),
+    details(0), brief(0), body(0), 
+    outerScope(0)
+{
+}
+
+DefinitionImpl::~DefinitionImpl()
+{
+  delete sectionDict;
+  delete sourceRefByDict;
+  delete sourceRefsDict;
+  delete partOfGroups;
+  delete xrefListItems;
+  delete brief;
+  delete details;
+  delete body;
+}
+
+void DefinitionImpl::init(const char *df,int dl,
+                          const char *n,const char *b,
+                          const char *d)
+{
+  defFileName = df;
+  int lastDot = defFileName.findRev('.');
+  if (lastDot!=-1)
+  {
+    defFileExt = defFileName.mid(lastDot);
+  }
+  defLine = dl;
+  QCString name = n;
+  if (name!="<globalScope>") 
+  {
+    //extractNamespaceName(m_name,m_localName,ns);
+    localName=stripScope(n);
+  }
+  else
+  {
+    localName=n;
+  }
+  //printf("m_localName=%s\n",m_localName.data());
+
+  if (b)
+  {
+    brief = new DocInfo;
+    brief->doc = b;
+  }
+  else
+  {
+    brief = 0;
+  }
+
+  if (d)
+  {
+    details = new DocInfo;
+    details->doc = d;
+  }
+  else
+  {
+    details = 0;
+  }
+  body = 0;
+  sourceRefByDict=0;
+  sourceRefsDict=0;
+  sectionDict=0, 
+  outerScope=Doxygen::globalScope;
+  partOfGroups=0;
+  xrefListItems=0;
+  hidden = FALSE;
+}
+
+//-----------------------------------------------------------------------------------------
+
+void Definition::addToMap(const char *name,Definition *d)
 {
   QCString symbolName = name;
   int index=computeQualifiedIndex(symbolName);
   if (index!=-1) symbolName=symbolName.mid(index+2);
   if (!symbolName.isEmpty()) 
   {
-    DefinitionList *dl=Doxygen::symbolMap->find(symbolName);
-    if (dl==0)
-    {
-      dl = new DefinitionList;
-      Doxygen::symbolMap->append(symbolName,dl);
-    }
     //printf("******* adding symbol `%s' (%p)\n",symbolName.data(),d);
-    dl->append(d);
-    d->setSymbolName(symbolName);
+    DefinitionIntf *di=Doxygen::symbolMap->find(symbolName);
+    //printf("  addToMap(%p): looking for symbol %s: %p\n",d,symbolName.data(),di);
+    if (di==0) // new Symbol
+    {
+      //printf("  new symbol!\n");
+      Doxygen::symbolMap->insert(symbolName,d);
+    }
+    else // existing symbol
+    {
+      //printf("  existing symbol: ");
+      if (di->definitionType()==DefinitionIntf::TypeSymbolList) // already multiple symbols
+      {
+        //printf("adding to exiting list\n");
+        DefinitionList *dl = (DefinitionList*)di;
+        dl->append(d);
+      }
+      else // going from one to two symbols
+      {
+        Doxygen::symbolMap->take(symbolName);
+        DefinitionList *dl = new DefinitionList;
+        //printf("replacing symbol by list %p with elements %p and %p\n",dl,di,d);
+        dl->append((Definition*)di);
+        dl->append(d);
+        Doxygen::symbolMap->insert(symbolName,dl);
+      }
+    }
+
+    // auto resize if needed
+    static int sizeIndex=9;
+    if (Doxygen::symbolMap->size()>SDict_primes[sizeIndex])
+    {
+      Doxygen::symbolMap->resize(SDict_primes[++sizeIndex]);
+    }
+
+    d->_setSymbolName(symbolName);
   }
 }
 
-static void removeFromMap(Definition *d)
+void Definition::removeFromMap(Definition *d)
 {
   QCString symbolName = d->symbolName();
   int index=computeQualifiedIndex(symbolName);
@@ -66,12 +208,26 @@ static void removeFromMap(Definition *d)
   if (!symbolName.isEmpty()) 
   {
     //printf("******* removing symbol `%s' (%p)\n",symbolName.data(),d);
-    DefinitionList *dl=Doxygen::symbolMap->find(symbolName);
-    if (dl)
+    DefinitionIntf *di=Doxygen::symbolMap->find(symbolName);
+    if (di)
     {
-      ASSERT(dl!=0);
-      bool b = dl->removeRef(d);
-      ASSERT(b==TRUE);
+      ASSERT(di!=0);
+      if (di!=d) // symbolName not unique
+      {
+        //printf("  removing from list: %p!\n",di);
+        DefinitionList *dl = (DefinitionList*)di;
+        bool b = dl->removeRef(d);
+        ASSERT(b==TRUE);
+        if (dl->isEmpty())
+        {
+          Doxygen::symbolMap->take(symbolName);
+        }
+      }
+      else // symbolName unique
+      {
+        //printf("  removing symbol %p\n",di);
+        Doxygen::symbolMap->take(symbolName);
+      }
     }
   }
 }
@@ -80,62 +236,30 @@ Definition::Definition(const char *df,int dl,
                        const char *name,const char *b,
                        const char *d,bool isSymbol)
 {
-  //QCString ns;
-  //printf("Definition(%s) %p\n",name,this);
-  m_defFileName = df;
-  int lastDot = m_defFileName.findRev('.');
-  if (lastDot!=-1)
-  {
-    m_defFileExt = m_defFileName.mid(lastDot);
-  }
-  m_defLine = dl;
-  m_name=name; 
-  if (m_name!="<globalScope>") 
-  {
-    //extractNamespaceName(m_name,m_localName,ns);
-    m_localName=stripScope(name);
-  }
-  else
-  {
-    m_localName=name;
-  }
-  //printf("m_localName=%s\n",m_localName.data());
-  m_brief=b; 
-  m_doc=d; 
-  m_sectionDict=0, 
-  m_startBodyLine=m_endBodyLine=-1, 
-  m_bodyDef=0;
-  m_sourceRefByDict=0;
-  m_sourceRefsDict=0;
-  m_todoId=0;
-  m_testId=0;
-  m_bugId=0;
-  m_deprecatedId=0;
-  m_outerScope=Doxygen::globalScope;
-  m_partOfGroups=0;
-  m_xrefListItems=0;
-  m_briefLine=1;
-  m_briefFile=(QCString)"<"+name+">";
-  m_docLine=1;
-  m_docFile=(QCString)"<"+name+">";
+  m_name = name;
+  m_impl = new DefinitionImpl;
+  m_impl->init(df,dl,name,b,d);
   m_isSymbol = isSymbol;
-  m_hidden = FALSE;
-  if (m_isSymbol) addToMap(name,this);
+  if (isSymbol) addToMap(name,this);
 }
 
 Definition::~Definition()
 {
-  if (m_isSymbol) removeFromMap(this);
-  delete m_sectionDict;
-  delete m_sourceRefByDict;
-  delete m_sourceRefsDict;
-  delete m_partOfGroups;
-  delete m_xrefListItems;
+  if (m_isSymbol) 
+  {
+    removeFromMap(this);
+  }
+  if (m_impl)
+  {
+    delete m_impl;
+    m_impl=0;
+  }
 }
 
 void Definition::addSectionsToDefinition(QList<SectionInfo> *anchorList)
 {
   if (!anchorList) return;
+  makeResident();
   //printf("%s: addSectionsToDefinition(%d)\n",name().data(),anchorList->count());
   SectionInfo *si=anchorList->first();
   while (si)
@@ -148,13 +272,13 @@ void Definition::addSectionsToDefinition(QList<SectionInfo> *anchorList)
       gsi = new SectionInfo(*si);
       Doxygen::sectionDict.insert(si->label,gsi);
     }
-    if (m_sectionDict==0) 
+    if (m_impl->sectionDict==0) 
     {
-      m_sectionDict = new SectionDict(17);
+      m_impl->sectionDict = new SectionDict(17);
     }
-    if (m_sectionDict->find(gsi->label)==0)
+    if (m_impl->sectionDict->find(gsi->label)==0)
     {
-      m_sectionDict->insert(gsi->label,gsi);
+      m_impl->sectionDict->insert(gsi->label,gsi);
       gsi->definition = this;
     }
     si=anchorList->next();
@@ -163,10 +287,11 @@ void Definition::addSectionsToDefinition(QList<SectionInfo> *anchorList)
 
 void Definition::writeDocAnchorsToTagFile()
 {
-  if (!Config_getString("GENERATE_TAGFILE").isEmpty() && m_sectionDict)
+  makeResident();
+  if (!Config_getString("GENERATE_TAGFILE").isEmpty() && m_impl->sectionDict)
   {
     //printf("%s: writeDocAnchorsToTagFile(%d)\n",name().data(),m_sectionDict->count());
-    QDictIterator<SectionInfo> sdi(*m_sectionDict);
+    QDictIterator<SectionInfo> sdi(*m_impl->sectionDict);
     SectionInfo *si;
     for (;(si=sdi.current());++sdi)
     {
@@ -185,33 +310,11 @@ void Definition::writeDocAnchorsToTagFile()
 void Definition::setDocumentation(const char *d,const char *docFile,int docLine,bool stripWhiteSpace) 
 { 
   if (d==0) return;
+  makeResident();
   //printf("Definition::setDocumentation(%s,%s,%d,%d)\n",d,docFile,docLine,stripWhiteSpace);
   QCString doc = d;
   if (stripWhiteSpace)
   {
-#if 0
-    // strip leading empty lines in front of the text, but not the 
-    // leading spaces in front of the first line, so list items are 
-    // parsed with the correct indent
-    const char *p=d;
-    char c;
-    int s=0,so=0;
-    while ((c=*p) && (c==' ' || c=='\r' || c=='\n'))
-    {
-      if (c=='\n') so=s; 
-      p++;
-      s++;
-    }
-    if (c=='\0') return;
-    doc=d+so;
-    // zero any trailing whitespace
-    int e=doc.length()-1;
-    while (e>=0 && (c=doc.at(e)) && (c==' ' || c=='\r' || c=='\n'))
-    {
-      doc.at(e)='\0';
-      e--;
-    }
-#endif
     doc = stripLeadingAndTrailingEmptyLines(doc);
   }
   else // don't strip whitespace
@@ -219,9 +322,13 @@ void Definition::setDocumentation(const char *d,const char *docFile,int docLine,
     doc=d;
   }
   //printf("setting docs for %s: `%s'\n",name().data(),m_doc.data());
-  m_doc=doc;
-  m_docFile = docFile;
-  m_docLine = docLine;
+  if (m_impl->details==0)
+  {
+    m_impl->details = new DocInfo;
+  }
+  m_impl->details->doc  = doc;
+  m_impl->details->file = docFile;
+  m_impl->details->line = docLine;
 }
 
 #define uni_isupper(c) (QChar(c).category()==QChar::Letter_Uppercase)
@@ -233,22 +340,27 @@ void Definition::setBriefDescription(const char *b,const char *briefFile,int bri
   static bool needsDot = outputLanguage!="Japanese" && 
                          outputLanguage!="Chinese" &&
                          outputLanguage!="Korean";
+  makeResident();
 
   //fprintf(stderr,"Definition::setBriefDescription(%s,%s,%d)\n",b,briefFile,briefLine);
-  m_brief=QCString(b).stripWhiteSpace();
-  int bl=m_brief.length(); 
+  if (m_impl->brief==0)
+  {
+    m_impl->brief = new DocInfo;
+  }
+  m_impl->brief->doc=QCString(b).stripWhiteSpace();
+  int bl=m_impl->brief->doc.length(); 
   if (bl>0 && needsDot) // add punctuation if needed
   {
-    switch(m_brief.at(bl-1))
+    switch(m_impl->brief->doc.at(bl-1))
     {
       case '.': case '!': case '?': break;
       default: 
-        if (uni_isupper(m_brief.at(0))) m_brief+='.'; 
+        if (uni_isupper(m_impl->brief->doc.at(0))) m_impl->brief->doc+='.'; 
         break;
     }
   }
-  m_briefFile = briefFile;
-  m_briefLine = briefLine;
+  m_impl->brief->file = briefFile;
+  m_impl->brief->line = briefLine;
 }
 
 /*! Reads a fragment of code from file \a fileName starting at 
@@ -371,9 +483,11 @@ static bool readCodeFragment(const char *fileName,
 /*! Write a reference to the source code defining this definition */
 void Definition::writeSourceDef(OutputList &ol,const char *)
 {
+  makeResident();
   ol.pushGeneratorState();
   //printf("Definition::writeSourceRef %d %p\n",bodyLine,bodyDef);
-  if (Config_getBool("SOURCE_BROWSER") && m_startBodyLine!=-1 && m_bodyDef)
+  if (Config_getBool("SOURCE_BROWSER") && 
+      m_impl->body && m_impl->body->startLine!=-1 && m_impl->body->fileDef)
   {
     QCString refText = theTranslator->trDefinedAtLineInSourceFile();
     int lineMarkerPos = refText.find("@0");
@@ -381,8 +495,8 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
     if (lineMarkerPos!=-1 && fileMarkerPos!=-1) // should always pass this.
     {
       QCString lineStr,anchorStr;
-      lineStr.sprintf("%d",m_startBodyLine);
-      anchorStr.sprintf(Htags::useHtags ? "L%d" : "l%05d",m_startBodyLine);
+      lineStr.sprintf("%d",m_impl->body->startLine);
+      anchorStr.sprintf(Htags::useHtags ? "L%d" : "l%05d",m_impl->body->startLine);
       ol.newParagraph();
       if (lineMarkerPos<fileMarkerPos) // line marker before file marker
       {
@@ -390,7 +504,7 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
         ol.parseText(refText.left(lineMarkerPos)); 
         ol.disableAllBut(OutputGenerator::Html); 
         // write line link (HTML only)
-        ol.writeObjectLink(0,m_bodyDef->getSourceFileBase(),
+        ol.writeObjectLink(0,m_impl->body->fileDef->getSourceFileBase(),
             anchorStr,lineStr);
         ol.enableAll();
         ol.disable(OutputGenerator::Html);
@@ -404,12 +518,12 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
 
         ol.disableAllBut(OutputGenerator::Html); 
         // write file link (HTML only)
-        ol.writeObjectLink(0,m_bodyDef->getSourceFileBase(),
-            0,m_bodyDef->name());
+        ol.writeObjectLink(0,m_impl->body->fileDef->getSourceFileBase(),
+            0,m_impl->body->fileDef->name());
         ol.enableAll();
         ol.disable(OutputGenerator::Html);
         // write normal text (Latex/Man only)
-        ol.docify(m_bodyDef->name());
+        ol.docify(m_impl->body->fileDef->name());
         ol.enableAll();
         
         // write text right from file marker
@@ -422,12 +536,12 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
         ol.parseText(refText.left(fileMarkerPos)); 
         ol.disableAllBut(OutputGenerator::Html); 
         // write file link (HTML only)
-        ol.writeObjectLink(0,m_bodyDef->getSourceFileBase(),
-            0,m_bodyDef->name());
+        ol.writeObjectLink(0,m_impl->body->fileDef->getSourceFileBase(),
+            0,m_impl->body->fileDef->name());
         ol.enableAll();
         ol.disable(OutputGenerator::Html);
         // write normal text (Latex/Man only)
-        ol.docify(m_bodyDef->name());
+        ol.docify(m_impl->body->fileDef->name());
         ol.enableAll();
         
         // write text between markers
@@ -436,7 +550,7 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
 
         ol.disableAllBut(OutputGenerator::Html); 
         // write line link (HTML only)
-        ol.writeObjectLink(0,m_bodyDef->getSourceFileBase(),
+        ol.writeObjectLink(0,m_impl->body->fileDef->getSourceFileBase(),
             anchorStr,lineStr);
         ol.enableAll();
         ol.disable(OutputGenerator::Html);
@@ -457,37 +571,55 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
   ol.popGeneratorState();
 }
 
+void Definition::setBodySegment(int bls,int ble) 
+{
+  makeResident();
+  //printf("setBodySegment(%d,%d) for %s\n",bls,ble,name().data());
+  if (m_impl->body==0) m_impl->body = new BodyInfo;
+  m_impl->body->startLine=bls; 
+  m_impl->body->endLine=ble; 
+}
+
+void Definition::setBodyDef(FileDef *fd)         
+{
+  makeResident();
+  if (m_impl->body==0) m_impl->body = new BodyInfo;
+  m_impl->body->fileDef=fd; 
+}
+
 /*! Write code of this definition into the documentation */
 void Definition::writeInlineCode(OutputList &ol,const char *scopeName)
 {
+  makeResident();
   ol.pushGeneratorState();
   //printf("Source Fragment %s: %d-%d bodyDef=%p\n",name().data(),
   //        m_startBodyLine,m_endBodyLine,m_bodyDef);
-  if (Config_getBool("INLINE_SOURCES") && m_startBodyLine!=-1 && 
-      m_endBodyLine>=m_startBodyLine && m_bodyDef)
+  if (Config_getBool("INLINE_SOURCES") && 
+      m_impl->body && m_impl->body->startLine!=-1 && 
+      m_impl->body->endLine>=m_impl->body->startLine && m_impl->body->fileDef)
   {
     QCString codeFragment;
-    int actualStart=m_startBodyLine,actualEnd=m_endBodyLine;
-    if (readCodeFragment(m_bodyDef->absFilePath(),
+    int actualStart=m_impl->body->startLine,actualEnd=m_impl->body->endLine;
+    if (readCodeFragment(m_impl->body->fileDef->absFilePath(),
           actualStart,actualEnd,codeFragment)
        )
     {
-      ParserInterface *pIntf = Doxygen::parserManager->getParser(m_defFileExt);
+      ParserInterface *pIntf = Doxygen::parserManager->getParser(m_impl->defFileExt);
       pIntf->resetCodeParserState();
       //printf("Read:\n`%s'\n\n",codeFragment.data());
       MemberDef *thisMd = 0;
       if (definitionType()==TypeMember) thisMd = (MemberDef *)this;
       ol.startCodeFragment();
-      pIntf->parseCode(ol,           // codeOutIntf
-                       scopeName,    // scope
-                       codeFragment, // input
-                       FALSE,        // isExample
-                       0,            // exampleName
-                       m_bodyDef,    // fileDef
-                       actualStart,  // startLine
-                       actualEnd,    // endLine
-                       TRUE,         // inlineFragment
-                       thisMd        // memberDef
+      pIntf->parseCode(ol,               // codeOutIntf
+                       scopeName,        // scope
+                       codeFragment,     // input
+                       FALSE,            // isExample
+                       0,                // exampleName
+                       m_impl->body->fileDef,  // fileDef
+                       actualStart,      // startLine
+                       actualEnd,        // endLine
+                       TRUE,             // inlineFragment
+                       thisMd            // memberDef
                       );
       ol.endCodeFragment();
       ol.newParagraph();
@@ -499,7 +631,7 @@ void Definition::writeInlineCode(OutputList &ol,const char *scopeName)
 /*! Write a reference to the source code fragments in which this 
  *  definition is used.
  */
-void Definition::writeSourceRefList(OutputList &ol,const char *scopeName,
+void Definition::_writeSourceRefList(OutputList &ol,const char *scopeName,
     const QCString &text,MemberSDict *members,bool /*funcOnly*/)
 {
   ol.pushGeneratorState();
@@ -592,37 +724,42 @@ void Definition::writeSourceRefList(OutputList &ol,const char *scopeName,
 
 void Definition::writeSourceReffedBy(OutputList &ol,const char *scopeName)
 {
+  makeResident();
   if (Config_getBool("REFERENCED_BY_RELATION"))
   {
-    writeSourceRefList(ol,scopeName,theTranslator->trReferencedBy(),m_sourceRefByDict,FALSE);
+    _writeSourceRefList(ol,scopeName,theTranslator->trReferencedBy(),m_impl->sourceRefByDict,FALSE);
   }
 }
 
 void Definition::writeSourceRefs(OutputList &ol,const char *scopeName)
 {
+  makeResident();
   if (Config_getBool("REFERENCES_RELATION"))
   {
-    writeSourceRefList(ol,scopeName,theTranslator->trReferences(),m_sourceRefsDict,TRUE);
+    _writeSourceRefList(ol,scopeName,theTranslator->trReferences(),m_impl->sourceRefsDict,TRUE);
   }
 }
 
 bool Definition::hasDocumentation() const
 { 
-  static bool extractAll = Config_getBool("EXTRACT_ALL"); 
+  static bool extractAll    = Config_getBool("EXTRACT_ALL"); 
   static bool sourceBrowser = Config_getBool("SOURCE_BROWSER");
+  makeResident();
   bool hasDocs = 
-         !m_doc.isEmpty() ||             // has detailed docs
-         !m_brief.isEmpty() ||           // has brief description
+         (m_impl->details && !m_impl->details->doc.isEmpty()) || // has detailed docs
+         (m_impl->brief && !m_impl->brief->doc.isEmpty())     || // has brief description
          extractAll ||                   // extract everything
-         (sourceBrowser && m_startBodyLine!=-1 && m_bodyDef); // link to definition
+         (sourceBrowser && m_impl->body && 
+          m_impl->body->startLine!=-1 && m_impl->body->fileDef); // link to definition
   return hasDocs;
 }
 
 bool Definition::hasUserDocumentation() const
 {
+  makeResident();
   bool hasDocs = 
-         !m_doc.isEmpty() ||
-         !m_brief.isEmpty();
+         (m_impl->details && !m_impl->details->doc.isEmpty()) ||
+         (m_impl->brief   && !m_impl->brief->doc.isEmpty());
   return hasDocs;
 }
 
@@ -630,6 +767,7 @@ void Definition::addSourceReferencedBy(MemberDef *md)
 {
   if (md)
   {
+    makeResident();
     QCString name  = md->name();
     QCString scope = md->getScopeString();
 
@@ -638,13 +776,13 @@ void Definition::addSourceReferencedBy(MemberDef *md)
       name.prepend(scope+"::");
     }
 
-    if (m_sourceRefByDict==0)
+    if (m_impl->sourceRefByDict==0)
     {
-      m_sourceRefByDict = new MemberSDict;
+      m_impl->sourceRefByDict = new MemberSDict;
     }
-    if (m_sourceRefByDict->find(name)==0)
+    if (m_impl->sourceRefByDict->find(name)==0)
     {
-      m_sourceRefByDict->inSort(name,md);
+      m_impl->sourceRefByDict->inSort(name,md);
     }
   }
 }
@@ -655,20 +793,21 @@ void Definition::addSourceReferences(MemberDef *md)
   {
     QCString name  = md->name();
     QCString scope = md->getScopeString();
+    makeResident();
 
     if (!scope.isEmpty())
     {
       name.prepend(scope+"::");
     }
 
-    if (m_sourceRefsDict==0)
+    if (m_impl->sourceRefsDict==0)
     {
-      m_sourceRefsDict = new MemberSDict;
+      m_impl->sourceRefsDict = new MemberSDict;
     }
-    if (m_sourceRefsDict->find(name)==0)
+    if (m_impl->sourceRefsDict->find(name)==0)
     {
       //printf("Adding reference %s->%s\n",md->name().data(),name.data());
-      m_sourceRefsDict->inSort(name,md);
+      m_impl->sourceRefsDict->inSort(name,md);
     }
   }
 }
@@ -685,100 +824,101 @@ void Definition::addInnerCompound(Definition *)
 
 QCString Definition::qualifiedName() 
 {
-  if (!m_qualifiedName.isEmpty()) return m_qualifiedName;
+  makeResident();
+  if (!m_impl->qualifiedName.isEmpty()) return m_impl->qualifiedName;
   
   //printf("start Definition::qualifiedName() localName=%s\n",m_localName.data());
-  if (m_outerScope==0) 
+  if (m_impl->outerScope==0) 
   {
-    if (m_localName=="<globalScope>") return "";
-    else return m_localName; 
+    if (m_impl->localName=="<globalScope>") return "";
+    else return m_impl->localName; 
   }
 
-  if (m_outerScope->name()=="<globalScope>")
+  if (m_impl->outerScope->name()=="<globalScope>")
   {
-    m_qualifiedName = m_localName.copy();
+    m_impl->qualifiedName = m_impl->localName.copy();
   }
   else
   {
-    m_qualifiedName = m_outerScope->qualifiedName()+"::"+m_localName;
+    m_impl->qualifiedName = m_impl->outerScope->qualifiedName()+"::"+m_impl->localName;
   }
   //printf("end Definition::qualifiedName()=%s\n",m_qualifiedName.data());
-  return m_qualifiedName;
+  return m_impl->qualifiedName;
 };
 
 void Definition::setOuterScope(Definition *d) 
 {
-  if (m_outerScope!=d)
+  makeResident();
+  if (m_impl->outerScope!=d)
   { 
-    m_qualifiedName.resize(0); // flush cached scope name
-    m_outerScope = d; 
+    m_impl->qualifiedName.resize(0); // flush cached scope name
+    m_impl->outerScope = d; 
   }
 }
 
 QCString Definition::localName() const
 {
-  return m_localName;
-}
-
-void Definition::setBodySegment(int bls,int ble) 
-{
-  //printf("setBodySegment(%d,%d) for %s\n",bls,ble,name().data());
-  m_startBodyLine=bls; 
-  m_endBodyLine=ble; 
+  makeResident();
+  return m_impl->localName;
 }
 
 void Definition::makePartOfGroup(GroupDef *gd)
 {
-  if (m_partOfGroups==0) m_partOfGroups = new GroupList;
-  m_partOfGroups->append(gd);
+  makeResident();
+  if (m_impl->partOfGroups==0) m_impl->partOfGroups = new GroupList;
+  m_impl->partOfGroups->append(gd);
 }
 
 void Definition::setRefItems(const QList<ListItemInfo> *sli)
 {
   if (sli)
   {
+    makeResident();
     // deep copy the list
-    if (m_xrefListItems==0) 
+    if (m_impl->xrefListItems==0) 
     {
-      m_xrefListItems=new QList<ListItemInfo>;
-      m_xrefListItems->setAutoDelete(TRUE);
+      m_impl->xrefListItems=new QList<ListItemInfo>;
+      m_impl->xrefListItems->setAutoDelete(TRUE);
     }
     QListIterator<ListItemInfo> slii(*sli);
     ListItemInfo *lii;
     for (slii.toFirst();(lii=slii.current());++slii)
     {
-      m_xrefListItems->append(new ListItemInfo(*lii));
+      m_impl->xrefListItems->append(new ListItemInfo(*lii));
     } 
   }
 }
 
 void Definition::mergeRefItems(Definition *d)
 {
-  if (d->xrefListItems())
+  LockingPtr< QList<ListItemInfo> > xrefList = d->xrefListItems();
+  if (xrefList!=0)
   {
+    makeResident();
     // deep copy the list
-    if (m_xrefListItems==0) 
+    if (m_impl->xrefListItems==0) 
     {
-      m_xrefListItems=new QList<ListItemInfo>;
-      m_xrefListItems->setAutoDelete(TRUE);
+      m_impl->xrefListItems=new QList<ListItemInfo>;
+      m_impl->xrefListItems->setAutoDelete(TRUE);
     }
-    QListIterator<ListItemInfo> slii(*d->xrefListItems());
+    QListIterator<ListItemInfo> slii(*xrefList);
     ListItemInfo *lii;
     for (slii.toFirst();(lii=slii.current());++slii)
     {
-      if (getXRefListId(lii->type)==-1)
+      if (_getXRefListId(lii->type)==-1)
       {
-        m_xrefListItems->append(new ListItemInfo(*lii));
+        m_impl->xrefListItems->append(new ListItemInfo(*lii));
       }
     } 
   }
 }
 
-int Definition::getXRefListId(const char *listName) const
+int Definition::_getXRefListId(const char *listName) const
 {
-  if (m_xrefListItems)
+  makeResident();
+  if (m_impl->xrefListItems)
   {
-    QListIterator<ListItemInfo> slii(*m_xrefListItems);
+    QListIterator<ListItemInfo> slii(*m_impl->xrefListItems);
     ListItemInfo *lii;
     for (slii.toFirst();(lii=slii.current());++slii)
     {
@@ -791,15 +931,17 @@ int Definition::getXRefListId(const char *listName) const
   return -1;
 }
 
-const QList<ListItemInfo> *Definition::xrefListItems() const
+LockingPtr< QList<ListItemInfo> > Definition::xrefListItems() const
 {
-  return m_xrefListItems;
+  makeResident();
+  return LockingPtr< QList<ListItemInfo> >(this,m_impl->xrefListItems);
 }
 
 
 QCString Definition::convertNameToFile(const char *name,bool allowDots) const
 {
-  if (!m_ref.isEmpty())
+  makeResident();
+  if (!m_impl->ref.isEmpty())
   {
     return name;
   }
@@ -811,11 +953,12 @@ QCString Definition::convertNameToFile(const char *name,bool allowDots) const
 
 void Definition::writePathFragment(OutputList &ol) const
 {
-  if (m_outerScope && m_outerScope!=Doxygen::globalScope)
+  makeResident();
+  if (m_impl->outerScope && m_impl->outerScope!=Doxygen::globalScope)
   {
-    m_outerScope->writePathFragment(ol);
-    if (m_outerScope->definitionType()==Definition::TypeClass ||
-        m_outerScope->definitionType()==Definition::TypeNamespace)
+    m_impl->outerScope->writePathFragment(ol);
+    if (m_impl->outerScope->definitionType()==Definition::TypeClass ||
+        m_impl->outerScope->definitionType()==Definition::TypeNamespace)
     {
       if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
       {
@@ -845,13 +988,13 @@ void Definition::writePathFragment(OutputList &ol) const
     }
     else
     {
-      ol.writeObjectLink(getReference(),getOutputFileBase(),0,m_localName);
+      ol.writeObjectLink(getReference(),getOutputFileBase(),0,m_impl->localName);
     }
   }
   else
   {
     ol.startBold();
-    ol.docify(m_localName);
+    ol.docify(m_impl->localName);
     ol.endBold();
   }
 }
@@ -868,3 +1011,215 @@ void Definition::writeNavigationPath(OutputList &ol) const
   ol.popGeneratorState();
 }
 
+QCString Definition::symbolName() const 
+{ 
+  return m_symbolName; 
+}
+
+QCString Definition::documentation() const 
+{ 
+  makeResident();
+  return m_impl->details ? m_impl->details->doc : QCString(""); 
+}
+
+int Definition::docLine() const 
+{ 
+  makeResident();
+  return m_impl->details ? m_impl->details->line : 1; 
+}
+
+QCString Definition::docFile() const 
+{ 
+  makeResident();
+  return m_impl->details ? m_impl->details->file : QCString("<"+m_name+">"); 
+}
+
+QCString Definition::briefDescription() const 
+{ 
+  makeResident();
+  return m_impl->brief ? m_impl->brief->doc : QCString(""); 
+}
+
+int Definition::briefLine() const 
+{ 
+  makeResident();
+  return m_impl->brief ? m_impl->brief->line : 1; 
+}
+
+QCString Definition::briefFile() const 
+{ 
+  makeResident();
+  return m_impl->brief ? m_impl->brief->file : QCString("<"+m_name+">"); 
+}
+
+QCString Definition::getDefFileName() const 
+{ 
+  makeResident();
+  return m_impl->defFileName; 
+}
+
+QCString Definition::getDefFileExtension() const 
+{ 
+  makeResident();
+  return m_impl->defFileExt; 
+}
+
+int Definition::getDefLine() const 
+{ 
+  makeResident();
+  return m_impl->defLine; 
+}
+
+bool Definition::isHidden() const
+{
+  makeResident();
+  return m_impl->hidden;
+}
+
+bool Definition::isVisibleInProject() const 
+{ 
+  return isLinkableInProject() || m_impl->hidden; 
+}
+
+bool Definition::isVisible() const
+{ 
+  return isLinkable() || m_impl->hidden; 
+}
+
+QCString Definition::getReference() const 
+{ 
+  makeResident();
+  return m_impl->ref; 
+}
+
+bool Definition::isReference() const 
+{ 
+  makeResident();
+  return !m_impl->ref.isEmpty(); 
+}
+
+int Definition::getStartBodyLine() const         
+{ 
+  makeResident();
+  return m_impl->body ? m_impl->body->startLine : -1; 
+}
+
+int Definition::getEndBodyLine() const           
+{ 
+  makeResident();
+  return m_impl->body ? m_impl->body->endLine : -1; 
+}
+
+FileDef *Definition::getBodyDef()                
+{ 
+  makeResident();
+  return m_impl->body ? m_impl->body->fileDef : 0; 
+}
+
+LockingPtr<GroupList> Definition::partOfGroups() const 
+{ 
+  makeResident();
+  return LockingPtr<GroupList>(this,m_impl->partOfGroups); 
+}
+
+Definition *Definition::getOuterScope() const 
+{ 
+  makeResident();
+  return m_impl->outerScope; 
+}
+
+LockingPtr<MemberSDict> Definition::getReferencesMembers() const 
+{ 
+  makeResident();
+  return LockingPtr<MemberSDict>(this,m_impl->sourceRefsDict); 
+}
+
+LockingPtr<MemberSDict> Definition::getReferencedByMembers() const 
+{ 
+  makeResident();
+  return LockingPtr<MemberSDict>(this,m_impl->sourceRefByDict); 
+}
+
+void Definition::setReference(const char *r) 
+{ 
+  makeResident();
+  m_impl->ref=r; 
+}
+
+void Definition::_setSymbolName(const QCString &name) 
+{ 
+  m_symbolName=name; 
+}
+
+void Definition::setHidden(bool b) 
+{ 
+  makeResident();
+  m_impl->hidden = b; 
+}
+
+void Definition::setLocalName(const QCString name) 
+{ 
+  makeResident();
+  m_impl->localName=name; 
+}
+
+void Definition::makeResident() const
+{
+}
+
+
+void Definition::flushToDisk() const
+{
+  //printf("%p: Definition::flushToDisk()\n",this);
+  Definition *that = (Definition *)this;
+  //printf("Definition::flushToDisk(): pos=%d\n",(int)m_storagePos); 
+  marshalUInt(Doxygen::symbolStorage,START_MARKER);
+  marshalSectionDict  (Doxygen::symbolStorage,m_impl->sectionDict);
+  marshalMemberSDict  (Doxygen::symbolStorage,m_impl->sourceRefByDict);
+  marshalMemberSDict  (Doxygen::symbolStorage,m_impl->sourceRefsDict);
+  marshalItemInfoList (Doxygen::symbolStorage,m_impl->xrefListItems);
+  marshalGroupList    (Doxygen::symbolStorage,m_impl->partOfGroups);
+  marshalDocInfo      (Doxygen::symbolStorage,m_impl->details);
+  marshalDocInfo      (Doxygen::symbolStorage,m_impl->brief);
+  marshalBodyInfo     (Doxygen::symbolStorage,m_impl->body);
+  marshalQCString     (Doxygen::symbolStorage,m_impl->localName);
+  marshalQCString     (Doxygen::symbolStorage,m_impl->qualifiedName);
+  marshalQCString     (Doxygen::symbolStorage,m_impl->ref);
+  marshalBool         (Doxygen::symbolStorage,m_impl->hidden);
+  marshalObjPointer   (Doxygen::symbolStorage,m_impl->outerScope);
+  marshalQCString     (Doxygen::symbolStorage,m_impl->defFileName);
+  marshalInt          (Doxygen::symbolStorage,m_impl->defLine);
+  marshalQCString     (Doxygen::symbolStorage,m_impl->defFileExt);
+  marshalUInt(Doxygen::symbolStorage,END_MARKER);
+  delete that->m_impl;
+  that->m_impl = 0;
+}
+
+void Definition::loadFromDisk() const
+{
+  //printf("%p: Definition::loadFromDisk()\n",this);
+  Definition *that = (Definition *)this;
+  assert(m_impl==0);
+  that->m_impl = new DefinitionImpl;
+  uint marker = unmarshalUInt(Doxygen::symbolStorage);
+  assert(marker==START_MARKER);
+  m_impl->sectionDict     = unmarshalSectionDict  (Doxygen::symbolStorage);
+  m_impl->sourceRefByDict = unmarshalMemberSDict  (Doxygen::symbolStorage);
+  m_impl->sourceRefsDict  = unmarshalMemberSDict  (Doxygen::symbolStorage);
+  m_impl->xrefListItems   = unmarshalItemInfoList (Doxygen::symbolStorage);
+  m_impl->partOfGroups    = unmarshalGroupList    (Doxygen::symbolStorage);
+  m_impl->details         = unmarshalDocInfo      (Doxygen::symbolStorage);
+  m_impl->brief           = unmarshalDocInfo      (Doxygen::symbolStorage);
+  m_impl->body            = unmarshalBodyInfo     (Doxygen::symbolStorage);
+  m_impl->localName       = unmarshalQCString     (Doxygen::symbolStorage);
+  m_impl->qualifiedName   = unmarshalQCString     (Doxygen::symbolStorage);
+  m_impl->ref             = unmarshalQCString     (Doxygen::symbolStorage);
+  m_impl->hidden          = unmarshalBool         (Doxygen::symbolStorage);
+  m_impl->outerScope      = (Definition *)unmarshalObjPointer   (Doxygen::symbolStorage);
+  m_impl->defFileName     = unmarshalQCString     (Doxygen::symbolStorage);
+  m_impl->defLine         = unmarshalInt          (Doxygen::symbolStorage);
+  m_impl->defFileExt      = unmarshalQCString     (Doxygen::symbolStorage);
+  marker = unmarshalUInt(Doxygen::symbolStorage);
+  assert(marker==END_MARKER);
+}
+
