@@ -2,7 +2,7 @@
  *
  * $Id: definition.h,v 1.21 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,6 +21,9 @@
 #include "qtbc.h"
 #include <qlist.h>
 #include <qdict.h>
+#include <sys/types.h>
+
+#include "lockingptr.h"
 
 class FileDef;
 class OutputList;
@@ -32,6 +35,7 @@ class GroupList;
 struct ListItemInfo;
 struct SectionInfo;
 class Definition;
+class DefinitionImpl;
 
 struct ReachableDefinition
 {
@@ -40,18 +44,50 @@ struct ReachableDefinition
   int distance;
 };
 
-/*! The common base class of all entity definitions found in the sources. */
-class Definition
+struct DocInfo
+{
+    QCString doc;  
+    int      line;
+    QCString file;
+};
+
+struct BodyInfo
+{
+    int      startLine;   // line number of the start of the definition
+    int      endLine;     // line number of the end of the definition
+    FileDef *fileDef;     // file definition containing the function body
+};
+    
+/*! Abstract interface for a Definition or DefinitionList */
+class DefinitionIntf
 {
   public:
+    DefinitionIntf() {}
+    virtual ~DefinitionIntf() {}
     /*! Types of derived classes */
     enum DefType 
     { 
-      TypeClass, TypeMember, TypeFile, TypeGroup, 
-      TypeNamespace, TypePackage, TypePage, TypeDir
+      TypeClass      = 0, 
+      TypeFile       = 1, 
+      TypeNamespace  = 2, 
+      TypeMember     = 3, 
+      TypeGroup      = 4, 
+      TypePackage    = 5, 
+      TypePage       = 6, 
+      TypeDir        = 7, 
+      TypeSymbolList = 8
     };
     /*! Use this for dynamic inspection of the type of the derived class */
     virtual DefType definitionType() const = 0;
+};
+
+/*! The common base class of all entity definitions found in the sources. 
+ *  This can be a class or a member function, or a file, or a namespace, etc.
+ *  Use definitionType() to find which type of definition this is.
+ */
+class Definition : public DefinitionIntf, public LockableObj
+{
+  public:
     
     /*! Create a new definition */
     Definition(
@@ -62,16 +98,23 @@ class Definition
     /*! Destroys the definition */
     virtual ~Definition();
 
+    //-----------------------------------------------------------------------------------
+    // ----  getters -----
+    //-----------------------------------------------------------------------------------
+
     /*! Returns the name of the definition */
     const QCString& name() const { return m_name; }
 
-    /*! Returns the base name of the output file that contains this 
-     *  definition. 
+    /*! Returns the local name without any scope qualifiers. */
+    QCString localName() const;
+
+    /*! Returns the fully qualified name of this definition
      */
     virtual QCString qualifiedName();
 
-    /*! Returns the local name without any scope qualifiers. */
-    QCString localName() const;
+    /*! Returns the name of this definition as it appears in the symbol map.
+     */
+    QCString symbolName() const;
 
     /*! Returns the base file name (without extension) of this definition.
      *  as it is referenced to/written to disk.
@@ -82,46 +125,35 @@ class Definition
     virtual QCString getSourceFileBase() const { ASSERT(0); return "NULL"; }
 
     /*! Returns the detailed description of this definition */
-    const QCString& documentation() const { return m_doc; }
+    QCString documentation() const;
     
-    /*! Returns the brief description of this definition */
-    const QCString& briefDescription() const { return m_brief; }
-
-    /*! Sets a new \a name for the definition */
-    void setName(const char *name) { m_name=name; }
-
-    /*! Sets the documentation of this definition to \a d. */
-    void setDocumentation(const char *d,const char *docFile,int docLine,bool stripWhiteSpace=TRUE);
-
     /*! Returns the line number at which the detailed documentation was found. */
-    int docLine() const { return m_docLine; }
+    int docLine() const;
 
     /*! Returns the file in which the detailed documentation block was found. 
      *  This can differ from getDefFileName().
      */
-    QCString docFile() const { return m_docFile; }
+    QCString docFile() const;
 
-    /*! Sets the brief description of this definition to \a b.
-     *  A dot is added to the sentence if not available.
-     */
-    void setBriefDescription(const char *b,const char *briefFile,int briefLine);
+    /*! Returns the brief description of this definition */
+    QCString briefDescription() const;
 
     /*! Returns the line number at which the brief description was found. */
-    int briefLine() const { return m_briefLine; }
+    int briefLine() const;
 
     /*! Returns the file in which the brief description was found. 
      *  This can differ from getDefFileName().
      */
-    QCString briefFile() const { return m_briefFile; }
+    QCString briefFile() const;
 
     /*! returns the file in which this definition was found */
-    QCString getDefFileName() const { return m_defFileName; }
+    QCString getDefFileName() const;
 
     /*! returns the file in which this definition was found */
-    QCString getDefFileExtension() const { return m_defFileExt; }
+    QCString getDefFileExtension() const;
 
     /*! returns the line number at which the definition was found */
-    int getDefLine() const { return m_defLine; }
+    int getDefLine() const;
 
     /*! Returns TRUE iff the definition is documented 
      *  (which could be generated documentation) 
@@ -132,7 +164,6 @@ class Definition
     /*! Returns TRUE iff the definition is documented by the user. */
     virtual bool hasUserDocumentation() const;
 
-
     /*! Returns TRUE iff it is possible to link to this item within this
      *  project. 
      */
@@ -146,134 +177,134 @@ class Definition
     /*! Returns TRUE iff the name is part of this project and 
      *  may appear in the output 
      */
-    virtual bool isVisibleInProject() const 
-    { return m_hidden || isLinkableInProject(); }
+    virtual bool isVisibleInProject() const;
 
     /*! Returns TRUE iff the name may appear in the output */
-    virtual bool isVisible() const
-    { return m_hidden || isLinkable(); }
+    virtual bool isVisible() const;
+
+    bool isHidden() const;
 
     /*! If this definition was imported via a tag file, this function
      *  returns the tagfile for the external project. This can be
      *  translated into an external link target via 
      *  Doxygen::tagDestinationDict
      */
-    virtual QCString getReference() const { return m_ref; }
+    virtual QCString getReference() const;
 
     /*! Returns TRUE if this definition is imported via a tag file. */
-    virtual bool isReference() const { return !m_ref.isEmpty(); }
+    virtual bool isReference() const;
+
+    /*! Returns the first line of the body of this item (applicable to classes and 
+     *  functions).
+     */
+    int getStartBodyLine() const;
+
+    /*! Returns the last line of the body of this item (applicable to classes and 
+     *  functions).
+     */
+    int getEndBodyLine() const;
+
+    /*! Returns the file in which the body of this item is located or 0 if no
+     *  body is available.
+     */
+    FileDef *getBodyDef();
+
+    LockingPtr<GroupList> partOfGroups() const;
+
+    LockingPtr< QList<ListItemInfo> > xrefListItems() const;
+
+    virtual Definition *findInnerCompound(const char *name);
+    virtual Definition *getOuterScope() const;
+
+    LockingPtr<MemberSDict> getReferencesMembers() const;
+    LockingPtr<MemberSDict> getReferencedByMembers() const;
+
+    //-----------------------------------------------------------------------------------
+    // ----  setters -----
+    //-----------------------------------------------------------------------------------
+
+    /*! Sets a new \a name for the definition */
+    void setName(const char *name) { m_name = name; }
+
+    /*! Sets the documentation of this definition to \a d. */
+    void setDocumentation(const char *d,const char *docFile,int docLine,bool stripWhiteSpace=TRUE);
+
+    /*! Sets the brief description of this definition to \a b.
+     *  A dot is added to the sentence if not available.
+     */
+    void setBriefDescription(const char *b,const char *briefFile,int briefLine);
 
     /*! Sets the tag file id via which this definition was imported. */
-    void setReference(const char *r) { m_ref=r; }
-
-    /*! Returns the name of this definition as it appears in the symbol map.
-     */
-    QCString symbolName() const { return m_symbolName; }
-
-    /*! Sets the name of this definition as it should appear in the symbol map.
-     */
-    void setSymbolName(const QCString &name) { m_symbolName=name; }
+    void setReference(const char *r);
 
     /*! Add the list of anchors that mark the sections that are found in the 
      * documentation.
      */
     void addSectionsToDefinition(QList<SectionInfo> *anchorList);
 
-    /*! Writes the documentation anchors of the definition to 
-     *  the Doxygen::tagFile stream.
-     */
-    void writeDocAnchorsToTagFile();
-
-    bool isHidden() const { return m_hidden; }
-
     // source references
     void setBodySegment(int bls,int ble);
-    void setBodyDef(FileDef *fd)         { m_bodyDef=fd; }
-    int getStartBodyLine() const         { return m_startBodyLine; }
-    int getEndBodyLine() const           { return m_endBodyLine; }
-    FileDef *getBodyDef()                { return m_bodyDef; }
-    void writeSourceDef(OutputList &ol,const char *scopeName);
-    void writeInlineCode(OutputList &ol,const char *scopeName);
-    void writeSourceRefs(OutputList &ol,const char *scopeName);
-    void writeSourceReffedBy(OutputList &ol,const char *scopeName);
+    void setBodyDef(FileDef *fd);
     void addSourceReferencedBy(MemberDef *d);
     void addSourceReferences(MemberDef *d);
 
     void setRefItems(const QList<ListItemInfo> *sli);
     void mergeRefItems(Definition *d);
-    const QList<ListItemInfo> *xrefListItems() const;
-
-    virtual Definition *findInnerCompound(const char *name);
-    virtual Definition *getOuterScope() const { return m_outerScope; }
     virtual void addInnerCompound(Definition *d);
-    virtual void setOuterScope(Definition *d) { m_outerScope = d; }
+    virtual void setOuterScope(Definition *d);
 
-    MemberSDict *getReferencesMembers() const { return m_sourceRefsDict; }
-    MemberSDict *getReferencedByMembers() const { return m_sourceRefByDict; }
+    void setHidden(bool b);
+
+    //-----------------------------------------------------------------------------------
+    // --- actions ----
+    //-----------------------------------------------------------------------------------
 
-    void makePartOfGroup(GroupDef *gd);
-    GroupList *partOfGroups() const { return m_partOfGroups; }
     QCString convertNameToFile(const char *name,bool allowDots=FALSE) const;
-
+    void writeSourceDef(OutputList &ol,const char *scopeName);
+    void writeInlineCode(OutputList &ol,const char *scopeName);
+    void writeSourceRefs(OutputList &ol,const char *scopeName);
+    void writeSourceReffedBy(OutputList &ol,const char *scopeName);
+    void makePartOfGroup(GroupDef *gd);
     void writePathFragment(OutputList &ol) const;
     void writeNavigationPath(OutputList &ol) const;
     virtual void writeQuickMemberLinks(OutputList &,MemberDef *) const {}
 
-    void setHidden(bool b) { m_hidden = b; }
+    /*! Writes the documentation anchors of the definition to 
+     *  the Doxygen::tagFile stream.
+     */
+    void writeDocAnchorsToTagFile();
 
   protected:
-    void setLocalName(const QCString name) { m_localName=name; }
-    
-    int      m_startBodyLine;   // line number of the start of the definition
-    int      m_endBodyLine;     // line number of the end of the definition
-    FileDef *m_bodyDef;         // file definition containing the function body
+    void setLocalName(const QCString name);
 
-    // where the item was found
-    QCString m_defFileName;
-    int      m_defLine;
-    QCString m_defFileExt;
-
-    /*! The class, namespace in which this class is located 
-     */ 
-    Definition *m_outerScope;
-    QCString m_name;     // name of the definition
-    QCString m_localName;      // local (unqualified) name of the definition
-                               // in the future m_name should become m_localName
-    /*! List of groups this definition is part of */
-    GroupList *m_partOfGroups;
+    virtual void flushToDisk() const;
+    virtual void loadFromDisk() const;
+    virtual void makeResident() const;
+    void lock() const {}
+    void unlock() const {}
 
   private: 
-    int getXRefListId(const char *listName) const;
-    void writeSourceRefList(OutputList &ol,const char *scopeName,
-                       const QCString &text,MemberSDict *members,bool);
-    //QCString m_qualifiedName;  // name of the definition
-    QCString m_brief; // brief description
-    QCString m_doc;   // detailed description
-    QCString m_ref;   // reference to external documentation
-    SectionDict *m_sectionDict;  // dictionary of all sections
-    MemberSDict *m_sourceRefByDict;
-    MemberSDict *m_sourceRefsDict;
-    int m_testId;       // id for test list item
-    int m_todoId;       // id for todo list item
-    int m_bugId;        // id for bug list item
-    int m_deprecatedId; // id for deprecated list item
-    int m_docLine;
-    QCString m_docFile;
-    int m_briefLine;
-    QCString m_briefFile;
-    QList<ListItemInfo> *m_xrefListItems;
-    QCString m_symbolName;
-    bool m_isSymbol;
-    bool m_hidden;
 
-    
-    QCString m_qualifiedName;
+    static void addToMap(const char *name,Definition *d);
+    static void removeFromMap(Definition *d);
+
+    void _setSymbolName(const QCString &name);
+
+    int  _getXRefListId(const char *listName) const;
+    void _writeSourceRefList(OutputList &ol,const char *scopeName,
+                       const QCString &text,MemberSDict *members,bool);
+    DefinitionImpl *m_impl; // internal structure holding all private data
+    QCString m_name;
+    bool m_isSymbol;
+    QCString m_symbolName;
+
 };
 
-class DefinitionList : public QList<Definition>
+class DefinitionList : public QList<Definition>, public DefinitionIntf
 {
   public:
     ~DefinitionList() {}
+    DefType definitionType() const { return TypeSymbolList; }
     int compareItems(GCI item1,GCI item2)
     {
       return stricmp(((Definition *)item1)->name(),
