@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * 
+ * $Id: diagram.cpp,v 1.30 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -258,14 +258,17 @@ void DiagramRow::insertClass(DiagramItem *parent,ClassDef *cd,bool doBases,
   di->move(count()*gridWidth,level*gridHeight);
   append(di);
   BaseClassList *bcl=doBases ? cd->baseClasses() : cd->subClasses();
-  /* there are base/sub classes */
   int count=0;
-  BaseClassDef *bcd=bcl->first();
-  while (bcd)
+  if (bcl)
   {
-    ClassDef *ccd=bcd->classDef;
-    if (ccd && ccd->isVisibleInHierarchy() /*&& !ccd->visited*/) count++;
-    bcd=bcl->next();
+    /* there are base/sub classes */
+    BaseClassDef *bcd=bcl->first();
+    while (bcd)
+    {
+      ClassDef *ccd=bcd->classDef;
+      if (ccd && ccd->isVisibleInHierarchy() /*&& !ccd->visited*/) count++;
+      bcd=bcl->next();
+    }
   }
   if (count>0 && (prot!=Private || !doBases))
   {
@@ -925,7 +928,7 @@ void TreeDiagram::drawConnectors(QTextStream &t,Image *image,
 
 void clearVisitFlags()
 {
-  ClassSDict::Iterator cli(Doxygen::classSDict);
+  ClassSDict::Iterator cli(*Doxygen::classSDict);
   ClassDef *cd;
   for (;(cd=cli.current());++cli)
   {
@@ -1248,7 +1251,7 @@ void ClassDiagram::writeFigure(QTextStream &output,const char *path,
     epstopdfArgs.sprintf("\"%s.eps\" --outfile=\"%s.pdf\"",
                    epsBaseName.data(),epsBaseName.data());
     //printf("Converting eps using `%s'\n",epstopdfCmd.data());
-    if (iSystem("epstopdf",epstopdfArgs,TRUE)!=0)
+    if (iSystem("epstopdf",epstopdfArgs)!=0)
     {
        err("Error: Problems running epstopdf. Check your TeX installation!\n");
        return;
