@@ -579,30 +579,33 @@ static QCString convertLabel(const QCString &l)
   return result;
 }
 
-static void writeBoxMemberList(QTextStream &t,char prot,MemberList &ml,ClassDef *scope)
+static void writeBoxMemberList(QTextStream &t,char prot,MemberList *ml,ClassDef *scope)
 {
-  MemberListIterator mlia(ml);
-  MemberDef *mma;
-  for (mlia.toFirst();(mma = mlia.current());++mlia)
+  if (ml)
   {
-    if (mma->getClassDef() == scope)
+    MemberListIterator mlia(*ml);
+    MemberDef *mma;
+    for (mlia.toFirst();(mma = mlia.current());++mlia)
     {
-      t << prot << " " << convertLabel(mma->name());
-      if (!mma->isObjCMethod() && mma->isFunction()) t << "()";
-      t << "\\l";
-    }
-  }
-  // write member groups within the memberlist
-  MemberGroupList *mgl = ml.getMemberGroupList();
-  if (mgl)
-  {
-    MemberGroupListIterator mgli(*mgl);
-    MemberGroup *mg;
-    for (mgli.toFirst();(mg=mgli.current());++mgli)
-    {
-      if (mg->members())
+      if (mma->getClassDef() == scope)
       {
-        writeBoxMemberList(t,prot,*mg->members(),scope);
+        t << prot << " " << convertLabel(mma->name());
+        if (!mma->isObjCMethod() && mma->isFunction()) t << "()";
+        t << "\\l";
+      }
+    }
+    // write member groups within the memberlist
+    MemberGroupList *mgl = ml->getMemberGroupList();
+    if (mgl)
+    {
+      MemberGroupListIterator mgli(*mgl);
+      MemberGroup *mg;
+      for (mgli.toFirst();(mg=mgli.current());++mgli)
+      {
+        if (mg->members())
+        {
+          writeBoxMemberList(t,prot,mg->members(),scope);
+        }
       }
     }
   }
@@ -626,35 +629,35 @@ void DotNode::writeBox(QTextStream &t,
   {
     t << "{" << convertLabel(m_label);
     t << "\\n|";
-    writeBoxMemberList(t,'+',m_classDef->pubAttribs,m_classDef);
-    writeBoxMemberList(t,'+',m_classDef->pubStaticAttribs,m_classDef);
-    writeBoxMemberList(t,'~',m_classDef->pacAttribs,m_classDef);
-    writeBoxMemberList(t,'~',m_classDef->pacStaticAttribs,m_classDef);
-    writeBoxMemberList(t,'#',m_classDef->proAttribs,m_classDef);
-    writeBoxMemberList(t,'#',m_classDef->proStaticAttribs,m_classDef);
-    writeBoxMemberList(t,'-',m_classDef->priAttribs,m_classDef);
-    writeBoxMemberList(t,'-',m_classDef->priStaticAttribs,m_classDef);
+    writeBoxMemberList(t,'+',m_classDef->getMemberList(MemberList::pubAttribs),m_classDef);
+    writeBoxMemberList(t,'+',m_classDef->getMemberList(MemberList::pubStaticAttribs),m_classDef);
+    writeBoxMemberList(t,'~',m_classDef->getMemberList(MemberList::pacAttribs),m_classDef);
+    writeBoxMemberList(t,'~',m_classDef->getMemberList(MemberList::pacStaticAttribs),m_classDef);
+    writeBoxMemberList(t,'#',m_classDef->getMemberList(MemberList::proAttribs),m_classDef);
+    writeBoxMemberList(t,'#',m_classDef->getMemberList(MemberList::proStaticAttribs),m_classDef);
+    writeBoxMemberList(t,'-',m_classDef->getMemberList(MemberList::priAttribs),m_classDef);
+    writeBoxMemberList(t,'-',m_classDef->getMemberList(MemberList::priStaticAttribs),m_classDef);
     t << "|";
-    writeBoxMemberList(t,'+',m_classDef->pubMethods,m_classDef);
-    writeBoxMemberList(t,'+',m_classDef->pubStaticMethods,m_classDef);
-    writeBoxMemberList(t,'+',m_classDef->pubSlots,m_classDef);
-    writeBoxMemberList(t,'~',m_classDef->pacMethods,m_classDef);
-    writeBoxMemberList(t,'~',m_classDef->pacStaticMethods,m_classDef);
-    writeBoxMemberList(t,'#',m_classDef->proMethods,m_classDef);
-    writeBoxMemberList(t,'#',m_classDef->proStaticMethods,m_classDef);
-    writeBoxMemberList(t,'#',m_classDef->proSlots,m_classDef);
-    writeBoxMemberList(t,'-',m_classDef->priMethods,m_classDef);
-    writeBoxMemberList(t,'-',m_classDef->priStaticMethods,m_classDef);
-    writeBoxMemberList(t,'-',m_classDef->priSlots,m_classDef);
-    if (m_classDef->memberGroupSDict)
+    writeBoxMemberList(t,'+',m_classDef->getMemberList(MemberList::pubMethods),m_classDef);
+    writeBoxMemberList(t,'+',m_classDef->getMemberList(MemberList::pubStaticMethods),m_classDef);
+    writeBoxMemberList(t,'+',m_classDef->getMemberList(MemberList::pubSlots),m_classDef);
+    writeBoxMemberList(t,'~',m_classDef->getMemberList(MemberList::pacMethods),m_classDef);
+    writeBoxMemberList(t,'~',m_classDef->getMemberList(MemberList::pacStaticMethods),m_classDef);
+    writeBoxMemberList(t,'#',m_classDef->getMemberList(MemberList::proMethods),m_classDef);
+    writeBoxMemberList(t,'#',m_classDef->getMemberList(MemberList::proStaticMethods),m_classDef);
+    writeBoxMemberList(t,'#',m_classDef->getMemberList(MemberList::proSlots),m_classDef);
+    writeBoxMemberList(t,'-',m_classDef->getMemberList(MemberList::priMethods),m_classDef);
+    writeBoxMemberList(t,'-',m_classDef->getMemberList(MemberList::priStaticMethods),m_classDef);
+    writeBoxMemberList(t,'-',m_classDef->getMemberList(MemberList::priSlots),m_classDef);
+    if (m_classDef->getMemberGroupSDict())
     {
-      MemberGroupSDict::Iterator mgdi(*m_classDef->memberGroupSDict);
+      MemberGroupSDict::Iterator mgdi(*m_classDef->getMemberGroupSDict());
       MemberGroup *mg;
       for (mgdi.toFirst();(mg=mgdi.current());++mgdi)
       {
         if (mg->members())
         {
-          writeBoxMemberList(t,'*',*mg->members(),m_classDef);
+          writeBoxMemberList(t,'*',mg->members(),m_classDef);
         }
       }
     }
@@ -1149,62 +1152,65 @@ void DotGfxHierarchyTable::writeGraph(QTextStream &out,const char *path)
 void DotGfxHierarchyTable::addHierarchy(DotNode *n,ClassDef *cd,bool hideSuper)
 {
   //printf("addHierarchy `%s' baseClasses=%d\n",cd->name().data(),cd->baseClasses()->count());
-  BaseClassListIterator bcli(*cd->subClasses());
-  BaseClassDef *bcd;
-  for ( ; (bcd=bcli.current()) ; ++bcli )
+  if (cd->subClasses())
   {
-    ClassDef *bClass=bcd->classDef; 
-    //printf("  Trying sub class=`%s' usedNodes=%d\n",bClass->name().data(),m_usedNodes->count());
-    if (bClass->isVisibleInHierarchy() && hasVisibleRoot(bClass->baseClasses()))
+    BaseClassListIterator bcli(*cd->subClasses());
+    BaseClassDef *bcd;
+    for ( ; (bcd=bcli.current()) ; ++bcli )
     {
-      DotNode *bn;
-      //printf("  Node `%s' Found visible class=`%s'\n",n->m_label.data(),
-      //                                              bClass->name().data());
-      if ((bn=m_usedNodes->find(bClass->name()))) // node already present 
+      ClassDef *bClass=bcd->classDef; 
+      //printf("  Trying sub class=`%s' usedNodes=%d\n",bClass->name().data(),m_usedNodes->count());
+      if (bClass->isVisibleInHierarchy() && hasVisibleRoot(bClass->baseClasses()))
       {
-        if (n->m_children==0 || n->m_children->findRef(bn)==-1) // no arrow yet
+        DotNode *bn;
+        //printf("  Node `%s' Found visible class=`%s'\n",n->m_label.data(),
+        //                                              bClass->name().data());
+        if ((bn=m_usedNodes->find(bClass->name()))) // node already present 
         {
+          if (n->m_children==0 || n->m_children->findRef(bn)==-1) // no arrow yet
+          {
+            n->addChild(bn,bcd->prot);
+            bn->addParent(n);
+            //printf("  Adding node %s to existing base node %s (c=%d,p=%d)\n",
+            //       n->m_label.data(),
+            //       bn->m_label.data(),
+            //       bn->m_children ? bn->m_children->count() : 0,
+            //       bn->m_parents  ? bn->m_parents->count()  : 0
+            //     );
+          }
+          //else
+          //{
+          //  printf("  Class already has an arrow!\n");
+          //}
+        }
+        else 
+        {
+          QCString tmp_url="";
+          if (bClass->isLinkable() && !bClass->isHidden())
+          {
+            tmp_url=bClass->getReference()+"$"+bClass->getOutputFileBase();
+          }
+          bn = new DotNode(m_curNodeNumber++,
+              bClass->displayName(),
+              tmp_url.data()
+              );
           n->addChild(bn,bcd->prot);
           bn->addParent(n);
-          //printf("  Adding node %s to existing base node %s (c=%d,p=%d)\n",
-          //       n->m_label.data(),
-          //       bn->m_label.data(),
-          //       bn->m_children ? bn->m_children->count() : 0,
-          //       bn->m_parents  ? bn->m_parents->count()  : 0
-          //     );
+          //printf("  Adding node %s to new base node %s (c=%d,p=%d)\n",
+          //   n->m_label.data(),
+          //   bn->m_label.data(),
+          //   bn->m_children ? bn->m_children->count() : 0,
+          //   bn->m_parents  ? bn->m_parents->count()  : 0
+          //  );
+          //printf("  inserting %s (%p)\n",bClass->name().data(),bn);
+          m_usedNodes->insert(bClass->name(),bn); // add node to the used list
         }
-        //else
-        //{
-        //  printf("  Class already has an arrow!\n");
-        //}
-      }
-      else 
-      {
-        QCString tmp_url="";
-        if (bClass->isLinkable() && !bClass->isHidden())
+        if (!bClass->visited && !hideSuper && bClass->subClasses())
         {
-          tmp_url=bClass->getReference()+"$"+bClass->getOutputFileBase();
+          bool wasVisited=bClass->visited;
+          bClass->visited=TRUE;
+          addHierarchy(bn,bClass,wasVisited);
         }
-        bn = new DotNode(m_curNodeNumber++,
-             bClass->displayName(),
-             tmp_url.data()
-           );
-        n->addChild(bn,bcd->prot);
-        bn->addParent(n);
-        //printf("  Adding node %s to new base node %s (c=%d,p=%d)\n",
-        //   n->m_label.data(),
-        //   bn->m_label.data(),
-        //   bn->m_children ? bn->m_children->count() : 0,
-        //   bn->m_parents  ? bn->m_parents->count()  : 0
-        //  );
-        //printf("  inserting %s (%p)\n",bClass->name().data(),bn);
-        m_usedNodes->insert(bClass->name(),bn); // add node to the used list
-      }
-      if (!bClass->visited && !hideSuper && bClass->subClasses()->count()>0)
-      {
-        bool wasVisited=bClass->visited;
-        bClass->visited=TRUE;
-        addHierarchy(bn,bClass,wasVisited);
       }
     }
   }
@@ -1235,7 +1241,7 @@ void DotGfxHierarchyTable::addClassList(ClassSDict *cl)
       //m_usedNodes->clear();
       m_usedNodes->insert(cd->name(),n);
       m_rootNodes->insert(0,n);   
-      if (!cd->visited && cd->subClasses()->count()>0)
+      if (!cd->visited && cd->subClasses())
       {
         addHierarchy(n,cd,cd->visited);
         cd->visited=TRUE;
@@ -1254,10 +1260,10 @@ DotGfxHierarchyTable::DotGfxHierarchyTable()
   
   // build a graph with each class as a node and the inheritance relations
   // as edges
-  initClassHierarchy(&Doxygen::classSDict);
-  initClassHierarchy(&Doxygen::hiddenClasses);
-  addClassList(&Doxygen::classSDict);
-  addClassList(&Doxygen::hiddenClasses);
+  initClassHierarchy(Doxygen::classSDict);
+  initClassHierarchy(Doxygen::hiddenClasses);
+  addClassList(Doxygen::classSDict);
+  addClassList(Doxygen::hiddenClasses);
   // m_usedNodes now contains all nodes in the graph
  
   // color the graph into a set of independent subgraphs
@@ -1400,14 +1406,18 @@ void DotClassGraph::buildGraph(ClassDef *cd,DotNode *n,int distance,bool base)
 
   if (m_graphType == DotNode::Inheritance || m_graphType==DotNode::Collaboration)
   {
-    BaseClassListIterator bcli(base ? *cd->baseClasses() : *cd->subClasses());
-    BaseClassDef *bcd;
-    for ( ; (bcd=bcli.current()) ; ++bcli )
+    BaseClassList *bcl = base ? cd->baseClasses() : cd->subClasses();
+    if (bcl)
     {
-      //printf("-------- inheritance relation %s->%s templ=`%s'\n",
-      //            cd->name().data(),bcd->classDef->name().data(),bcd->templSpecifiers.data());
-      addClass(bcd->classDef,n,bcd->prot,0,distance,bcd->usedName,
-          bcd->templSpecifiers,base); 
+      BaseClassListIterator bcli(*bcl);
+      BaseClassDef *bcd;
+      for ( ; (bcd=bcli.current()) ; ++bcli )
+      {
+        //printf("-------- inheritance relation %s->%s templ=`%s'\n",
+        //            cd->name().data(),bcd->classDef->name().data(),bcd->templSpecifiers.data());
+        addClass(bcd->classDef,n,bcd->prot,0,distance,bcd->usedName,
+            bcd->templSpecifiers,base); 
+      }
     }
   }
   if (m_graphType == DotNode::Collaboration)
@@ -1948,53 +1958,56 @@ void DotInclDepGraph::buildGraph(DotNode *n,FileDef *fd,int distance)
 {
   QList<IncludeInfo> *includeFiles = 
      m_inverse ? fd->includedByFileList() : fd->includeFileList();
-  QListIterator<IncludeInfo> ili(*includeFiles);
-  IncludeInfo *ii;
-  for (;(ii=ili.current());++ili)
+  if (includeFiles)
   {
-    FileDef *bfd = ii->fileDef;
-    QCString in  = ii->includeName;
-    //printf(">>>> in=`%s' bfd=%p\n",ii->includeName.data(),bfd);
-    bool doc=TRUE,src=FALSE;
-    if (bfd)
+    QListIterator<IncludeInfo> ili(*includeFiles);
+    IncludeInfo *ii;
+    for (;(ii=ili.current());++ili)
     {
-      in  = bfd->absFilePath();  
-      doc = bfd->isLinkable() && !bfd->isHidden();
-      src = bfd->generateSourceFile();
-    }
-    if (doc || src || !Config_getBool("HIDE_UNDOC_RELATIONS"))
-    {
-      QCString url="";
-      if (bfd) url=bfd->getOutputFileBase().copy();
-      if (!doc && src)
+      FileDef *bfd = ii->fileDef;
+      QCString in  = ii->includeName;
+      //printf(">>>> in=`%s' bfd=%p\n",ii->includeName.data(),bfd);
+      bool doc=TRUE,src=FALSE;
+      if (bfd)
       {
-        url=bfd->getSourceFileBase();
+        in  = bfd->absFilePath();  
+        doc = bfd->isLinkable() && !bfd->isHidden();
+        src = bfd->generateSourceFile();
       }
-      DotNode *bn  = m_usedNodes->find(in);
-      if (bn) // file is already a node in the graph
+      if (doc || src || !Config_getBool("HIDE_UNDOC_RELATIONS"))
       {
-        n->addChild(bn,0,0,0);
-        bn->addParent(n);
-        bn->setDistance(distance);
-      }
-      else
-      {
-        QCString tmp_url;
-        if (bfd) tmp_url=doc || src ? bfd->getReference()+"$"+url : QCString();
-        bn = new DotNode(
-                          m_curNodeNumber++,
-                          ii->includeName,
-                          tmp_url,
-                          distance
-                        );
-        if (distance>m_maxDistance) m_maxDistance=distance;
-        n->addChild(bn,0,0,0);
-        bn->addParent(n);
-        m_usedNodes->insert(in,bn);
+        QCString url="";
+        if (bfd) url=bfd->getOutputFileBase().copy();
+        if (!doc && src)
+        {
+          url=bfd->getSourceFileBase();
+        }
+        DotNode *bn  = m_usedNodes->find(in);
+        if (bn) // file is already a node in the graph
+        {
+          n->addChild(bn,0,0,0);
+          bn->addParent(n);
+          bn->setDistance(distance);
+        }
+        else
+        {
+          QCString tmp_url;
+          if (bfd) tmp_url=doc || src ? bfd->getReference()+"$"+url : QCString();
+          bn = new DotNode(
+              m_curNodeNumber++,
+              ii->includeName,
+              tmp_url,
+              distance
+              );
+          if (distance>m_maxDistance) m_maxDistance=distance;
+          n->addChild(bn,0,0,0);
+          bn->addParent(n);
+          m_usedNodes->insert(in,bn);
 
-        // we use <=, i.s.o < to cause one more level than intended which is used to 
-        // detect truncated nodes
-        if (bfd && distance<=m_recDepth) buildGraph(bn,bfd,distance+1);
+          // we use <=, i.s.o < to cause one more level than intended which is used to 
+          // detect truncated nodes
+          if (bfd && distance<=m_recDepth) buildGraph(bn,bfd,distance+1);
+        }
       }
     }
   }
@@ -2346,8 +2359,8 @@ QCString DotCallGraph::writeGraph(QTextStream &out, GraphOutputFormat format,
 
 void DotCallGraph::buildGraph(DotNode *n,MemberDef *md,int distance)
 {
-  MemberSDict *refs = m_inverse ? md->getReferencedByMembers() : md->getReferencesMembers();
-  if (refs)
+  LockingPtr<MemberSDict> refs = m_inverse ? md->getReferencedByMembers() : md->getReferencesMembers();
+  if (!refs.isNull())
   {
     MemberSDict::Iterator mri(*refs);
     MemberDef *rmd;
@@ -2531,8 +2544,6 @@ QCString DotDirDeps::writeGraph(QTextStream &out,
 
   QDir::setCurrent(oldDir);
   return baseName;
-
-
 }
 
 bool DotDirDeps::isTrivial() const
@@ -2722,9 +2733,10 @@ void DotGroupCollaboration::buildGraph(GroupDef* gd,int)
   // hierarchy.
 
   // Write parents
-  if ( gd->partOfGroups() )
+  LockingPtr<GroupList> groups = gd->partOfGroups();
+  if ( groups!=0 )
   {
-    GroupListIterator gli(*gd->partOfGroups());
+    GroupListIterator gli(*groups);
     GroupDef *d;
     for (gli.toFirst();(d=gli.current());++gli)
     {
@@ -2763,7 +2775,7 @@ void DotGroupCollaboration::buildGraph(GroupDef* gd,int)
   // Write collaboration
 
   // Add members
-  addMemberList( gd->getMembers() );
+  addMemberList( gd->getMemberList(MemberList::allMembersList) );
 
   // Add classes
   if ( gd->getClasses() && gd->getClasses()->count() )
