@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: entry.h,v 1.36 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,7 +21,13 @@
 #include "qtbc.h"
 #include <qlist.h>
 
+#include <qgstring.h>
+
 struct SectionInfo;
+class QFile;
+class EntryNav;
+class FileDef;
+class FileStorage;
 
 enum Protection { Public, Protected, Private, Package } ;
 enum Specifier { Normal, Virtual, Pure } ;
@@ -246,40 +252,59 @@ class Entry
       Final     = 0x0080,
       Abstract  = 0x0100,
     };
+    enum GroupDocType
+    {
+      GROUPDOC_NORMAL,        //!< defgroup
+      GROUPDOC_ADD,           //!< addgroup
+      GROUPDOC_WEAK           //!< weakgroup
+    };                        //!< kind of group
+
 
     Entry();
     Entry(const Entry &);
     ~Entry();
     int getSize();
     void addSpecialListItem(const char *listName,int index);
+    void createNavigationIndex(EntryNav *rootNav,FileStorage *storage,FileDef *fd);
+
+    // while parsing a file these function can be used to navigate/build the tree
+    void setParent(Entry *parent) { m_parent = parent; }
+    Entry *parent() const { return m_parent; }
+    const QList<Entry> *children() const { return m_sublist; }
 
     /*! Adds entry \e as a child to this entry */
     void	addSubEntry (Entry* e) ;
     /*! Restore the state of this Entry to the default value it has
      *  at construction time. 
      */
-    void        reset();
+    void reset();
 
-    int        section;       //!< entry type (see Sections);
+  public:
+
+    // identification
+    int          section;     //!< entry type (see Sections);
+    QCString	 type;        //!< member type 
+    QCString	 name;        //!< member name
+    TagInfo     *tagInfo;     //!< tag file info
+
+    // content
     Protection protection;    //!< class protection
     MethodTypes mtype;        //!< signal, slot, (dcop) method, or property?
+    int  memSpec;             //!< member specifiers
+    int  initLines;           //!< define/variable initializer lines to show 
     bool stat;                //!< static ?
     bool explicitExternal;    //!< explicitly defined as external?
     bool proto;               //!< prototype ?
-    int  memSpec;             //!< member specifiers
-    int  initLines;           //!< define/variable initializer lines to show 
     bool subGrouping;         //!< automatically group class members?
     bool callGraph;           //!< do we need to draw the call graph?
+    bool callerGraph;         //!< do we need to draw the caller graph?
     Specifier    virt;        //!< virtualness of the entry 
-    Entry       *parent;      //!< parent node in the tree
-    QCString	 type;        //!< member type 
-    QCString	 name;        //!< member name
     QCString     args;        //!< member argument string
     QCString     bitfields;   //!< member's bit fields
     ArgumentList *argList;    //!< member arguments as a list
     QList<ArgumentList> *tArgLists; //!< template argument declarations
-    QCString	 program;     //!< the program text
-    QCString     initializer; //!< initial value (for variables)
+    QGString	 program;     //!< the program text
+    QGString     initializer; //!< initial value (for variables)
     QCString     includeFile; //!< include file (2 arg of \\class, must be unique)
     QCString     includeName; //!< include name (3 arg of \\class)
     QCString     doc;         //!< documentation block (partly parsed)
@@ -300,22 +325,18 @@ class Entry
     int          bodyLine;    //!< line number of the definition in the source
     int          endBodyLine; //!< line number where the definition ends
     int          mGrpId;      //!< member group id
-    QList<Entry>    *sublist; //!< entries that are children of this one
     QList<BaseInfo> *extends; //!< list of base classes    
     QList<Grouping> *groups;  //!< list of groups this entry belongs to
     QList<SectionInfo> *anchors; //!< list of anchors defined in this entry
     QCString	fileName;     //!< file this entry was extracted from
     int		startLine;    //!< start line of entry in the source
     QList<ListItemInfo> *sli; //!< special lists (test/todo/bug/deprecated/..) this entry is in
-    TagInfo    *tagInfo;      //!< tag file info
-    static int  num;          //!< counts the total number of entries
     bool        objc;         //!< Objective-C construct
-    enum 
-    {
-      GROUPDOC_NORMAL,        //!< defgroup
-      GROUPDOC_ADD,           //!< addgroup
-      GROUPDOC_WEAK           //!< weakgroup
-    } groupDocType;           //!< kind of group
+    bool        hidden;       //!< does this represent an entity that is hidden from the output
+    GroupDocType groupDocType;
+
+    static int  num;          //!< counts the total number of entries
+
     /// return the command name used to define GROUPDOC_SEC
     const char *groupDocCmd() const
     {
@@ -341,11 +362,59 @@ class Entry
         default: return Grouping::GROUPING_LOWEST;
       }
     }
-  private:
+
+  private:  
+    void createSubtreeIndex(EntryNav *nav,FileStorage *storage,FileDef *fd);
+    Entry         *m_parent;    //!< parent node in the tree
+    QList<Entry>  *m_sublist;   //!< entries that are children of this one
     Entry &operator=(const Entry &); 
-} ;
+};
+
+class EntryNav
+{
+  public:
+    EntryNav(EntryNav *parent,Entry *e);
+   ~EntryNav();
+    void addChild(EntryNav *);
+    bool loadEntry(FileStorage *storage);
+    bool saveEntry(Entry *e,FileStorage *storage);
+    void setEntry(Entry *e);
+    void releaseEntry();
+    void changeSection(int section) { m_section = section; }
+    void setFileDef(FileDef *fd) { m_fileDef = fd; }
+
+    Entry *entry() const { return m_info; }
+    int section() const { return m_section; }
+    const QCString &type() const { return m_type; }
+    const QCString &name() const { return m_name; }
+    TagInfo *tagInfo() const { return m_tagInfo; }
+    const QList<EntryNav> *children() const { return m_subList; }
+    EntryNav *parent() const { return m_parent; }
+    FileDef *fileDef() const { return m_fileDef; }
+
+  private:
+
+    // navigation 
+    EntryNav        *m_parent;    //!< parent node in the tree
+    QList<EntryNav> *m_subList;   //!< entries that are children of this one
+
+    // identification
+    int          m_section;     //!< entry type (see Sections);
+    QCString	 m_type;        //!< member type 
+    QCString	 m_name;        //!< member name
+    TagInfo     *m_tagInfo;      //!< tag file info
+    FileDef     *m_fileDef;
+
+    Entry       *m_info;
+    int64        m_offset;
+    bool         m_noLoad;
+};
+
 
 typedef QList<Entry> EntryList;
 typedef QListIterator<Entry> EntryListIterator;
 
+typedef QList<EntryNav> EntryNavList;
+typedef QListIterator<EntryNav> EntryNavListIterator;
+
 #endif
