@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: filedef.h,v 1.32 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -79,6 +79,11 @@ class FileDef : public Definition
       else 
         return Definition::name(); 
     } 
+
+    QCString fileName() const
+    {
+      return filename;
+    }
     
     QCString getOutputFileBase() const 
     { return convertNameToFile(diskname); }
@@ -122,6 +127,8 @@ class FileDef : public Definition
     }
     bool isIncluded(const QCString &name) const;
 
+    bool isJava() const { return m_isJava; }
+
     void writeDetailedDocumentation(OutputList &ol);
     void writeDocumentation(OutputList &ol);
     void writeMemberDocumentation(OutputList &ol);
@@ -143,7 +150,7 @@ class FileDef : public Definition
     DirDef *getDirDef() const { return dir; }
 
     void addUsingDirective(NamespaceDef *nd);
-    NamespaceSDict *getUsedNamespaces() const { return usingDirList; }
+    NamespaceSDict *getUsedNamespaces() const;
     void addUsingDeclaration(Definition *def);
     SDict<Definition> *getUsedClasses() const { return usingDeclList; }
     void combineUsingRelations();
@@ -163,32 +170,13 @@ class FileDef : public Definition
     void addListReferences();
     bool isDocumentationFile() const;
 
-    //void generateXML(QTextStream &t);
-    //void generateXMLSection(QTextStream &t,MemberList *ml,const char *type);
-
-    MemberList allMemberList;
-
-    // members in the declaration part of the documentation
-    MemberList decDefineMembers;
-    MemberList decProtoMembers;
-    MemberList decTypedefMembers;
-    MemberList decEnumMembers;
-    MemberList decFuncMembers;
-    MemberList decVarMembers;
-
-    // members in the detailed part of the documentation
-    MemberList docDefineMembers;
-    MemberList docProtoMembers;
-    MemberList docTypedefMembers;
-    MemberList docEnumMembers;
-    MemberList docFuncMembers;
-    MemberList docVarMembers;
+    MemberList *getMemberList(MemberList::ListType lt) const;
+    const QList<MemberList> &getMemberLists() const { return m_memberLists; }
 
     /* user defined member groups */
-    MemberGroupSDict *memberGroupSDict;
-
-    NamespaceSDict *namespaceSDict;
-    ClassSDict *classSDict;
+    MemberGroupSDict *getMemberGroupSDict() const { return memberGroupSDict; }
+    NamespaceSDict *getNamespaceSDict() const     { return namespaceSDict; }
+    ClassSDict *getClassSDict() const             { return classSDict; }
     
     bool visited;
 
@@ -198,27 +186,35 @@ class FileDef : public Definition
      */
     void acquireFileVersion();
 
-
   private: 
-    
-    QDict<IncludeInfo> *includeDict;
-    QList<IncludeInfo> *includeList;
-    QDict<IncludeInfo> *includedByDict;
-    QList<IncludeInfo> *includedByList;
-    NamespaceSDict *usingDirList;
-    SDict<Definition> *usingDeclList;
-    QCString path;
-    QCString filepath;
-    QCString diskname;
-    QCString filename;
-    QCString docname;
-    QIntDict<Definition> *srcDefDict;
-    QIntDict<MemberDef> *srcMemberDict;
-    bool isSource;
-    QCString fileVersion;
+    MemberList *createMemberList(MemberList::ListType lt);
+    void addMemberToList(MemberList::ListType lt,MemberDef *md);
+    void writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,const QCString &title);
+    void writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,const QCString &title);
 
-    PackageDef *package;
-    DirDef     *dir;
+    QDict<IncludeInfo>   *includeDict;
+    QList<IncludeInfo>   *includeList;
+    QDict<IncludeInfo>   *includedByDict;
+    QList<IncludeInfo>   *includedByList;
+    NamespaceSDict       *usingDirList;
+    SDict<Definition>    *usingDeclList;
+    QCString              path;
+    QCString              filepath;
+    QCString              diskname;
+    QCString              filename;
+    QCString              docname;
+    QIntDict<Definition> *srcDefDict;
+    QIntDict<MemberDef>  *srcMemberDict;
+    bool                  isSource;
+    bool                  m_isJava;
+    QCString              fileVersion;
+    PackageDef           *package;
+    DirDef               *dir;
+    QList<MemberList>     m_memberLists;
+    MemberGroupSDict     *memberGroupSDict;
+    NamespaceSDict       *namespaceSDict;
+    ClassSDict           *classSDict;
+    bool                  m_subGrouping;
 };
 
 
@@ -283,6 +279,7 @@ class DirEntry
   protected:
     DirEntry *m_parent;
     QCString m_name;
+
   private:
     EntryKind m_kind;
     FileDef   *m_fd;
