@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: htmlgen.h,v 1.51 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -45,7 +45,7 @@ class HtmlGenerator : public OutputGenerator
     bool isEnabled(OutputType o) { return (o==Html && active); } 
     OutputGenerator *get(OutputType o) { return (o==Html) ? this : 0; }
 
-    void printDoc(DocNode *);
+    void printDoc(DocNode *,const char *);
 
     void startFile(const char *name,const char *manName,const char *title);
     void writeFooter();
@@ -72,7 +72,8 @@ class HtmlGenerator : public OutputGenerator
     void endIndexValue(const char *,bool);
     void startItemList()  { t << "<ul>"  << endl; }
     void endItemList()    { t << "</ul>" << endl; }
-    void writeIndexItem(const char *ref,const char *file,const char *name);
+    void startIndexItem(const char *ref,const char *file);
+    void endIndexItem(const char *ref,const char *file);
     void docify(const char *text);
     void codify(const char *text);
     void writeObjectLink(const char *ref,const char *file,
@@ -95,6 +96,8 @@ class HtmlGenerator : public OutputGenerator
     void endMemberHeader();
     void startMemberSubtitle();
     void endMemberSubtitle();
+    void startMemberDocList();
+    void endMemberDocList();
     void startMemberList();
     void endMemberList();
     void startAnonTypeScope(int) {}
@@ -220,6 +223,8 @@ class HtmlGenerator : public OutputGenerator
 
     void writeCodeAnchor(const char *anchor) 
     { t << "<a name=\"" << anchor << "\"></a>"; }
+    void linkableSymbol(int,const char *,Definition *,Definition *) {}
+
     static void writeSearchPage();
 
   private:
