@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: index.h,v 1.28 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,6 +21,8 @@
 #include "qtbc.h"
 #include <qfile.h>
 
+class MemberDef;
+
 enum IndexSections
 {
   isTitlePageStart,
@@ -90,7 +92,11 @@ enum HighlightedItem
   HLI_Globals,
   HLI_Pages,
   HLI_Examples,
-  HLI_Search
+  HLI_Search,
+
+  HLI_ClassVisible,
+  HLI_NamespaceVisible,
+  HLI_FileVisible
 };
 
 enum ClassMemberHighlight
@@ -162,4 +168,11 @@ void startFile(OutputList &ol,const char *name,const char *manName,
                const char *title,HighlightedItem hli=HLI_None);
 void endFile(OutputList &ol,bool external=FALSE);
 
+void initClassMemberIndices();
+void initFileMemberIndices();
+void initNamespaceMemberIndices();
+void addClassMemberNameToIndex(MemberDef *md);
+void addFileMemberNameToIndex(MemberDef *md);
+void addNamespaceMemberNameToIndex(MemberDef *md);
+
 #endif
