@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: latexgen.h,v 1.50 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -43,7 +43,7 @@ class LatexGenerator : public OutputGenerator
     bool isEnabled(OutputType o) { return (o==Latex && active); } 
     OutputGenerator *get(OutputType o) { return (o==Latex) ? this : 0; }
 
-    void printDoc(DocNode *);
+    void printDoc(DocNode *,const char *);
 
     void startFile(const char *name,const char *manName,const char *title);
     void writeFooter() {}
@@ -70,7 +70,8 @@ class LatexGenerator : public OutputGenerator
     void endIndexValue(const char *,bool);
     void startItemList()  { t << "\\begin{CompactItemize}" << endl; }
     void endItemList()    { t << "\\end{CompactItemize}"   << endl; }
-    void writeIndexItem(const char *ref,const char *file,const char *name);
+    void startIndexItem(const char *ref,const char *file);
+    void endIndexItem(const char *ref,const char *file);
     void docify(const char *text);
     void codify(const char *text);
     void writeObjectLink(const char *ref,const char *file,
@@ -93,6 +94,8 @@ class LatexGenerator : public OutputGenerator
     void endMemberHeader();
     void startMemberSubtitle() {}
     void endMemberSubtitle() {}
+    void startMemberDocList() {}
+    void endMemberDocList() {}
     void startMemberList();
     void endMemberList();
     void startAnonTypeScope(int);
@@ -113,14 +116,14 @@ class LatexGenerator : public OutputGenerator
 
     void writeRuler() { t << endl << endl; /*t << "\\vspace{0.4cm}\\hrule\\vspace{0.2cm}" << endl; */ }
     void writeAnchor(const char *fileName,const char *name);
-    void startCodeFragment() { t << endl << endl << "\\footnotesize\\begin{verbatim}"; }
-    void endCodeFragment()   { t << "\\end{verbatim}\\normalsize " << endl; }
+    void startCodeFragment() { t << endl << endl << "\\begin{Code}\\begin{verbatim}"; }
+    void endCodeFragment()   { t << "\\end{verbatim}\\end{Code}" << endl; }
     void writeLineNumber(const char *,const char *,const char *,int l) { t << l << " "; }
     void startCodeLine() { col=0; }
     void endCodeLine() { codify("\n"); }
     void startEmphasis() { t << "{\\em ";  }
     void endEmphasis()   { t << "}"; }
-    void startBold()     { t << "{\\bf "; }
+    void startBold()     { t << "\\textbf{"; }
     void endBold()       { t << "}"; }
     void startDescription();
     void endDescription();
@@ -210,6 +213,7 @@ class LatexGenerator : public OutputGenerator
     void endFontClass() {}
 
     void writeCodeAnchor(const char *) {}
+    void linkableSymbol(int,const char *,Definition *,Definition *) {}
 
   private:
     LatexGenerator(const LatexGenerator &);
