@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * 
+ * $Id: main.cpp,v 1.86 2001/01/01 10:15:16 root Exp $
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -33,6 +33,7 @@ int main(int argc,char **argv)
   initDoxygen();
 
   readConfiguration(argc,argv);
+  checkConfiguration();
   parseInput();
   generateOutput();
   return 0;
