@@ -2,7 +2,7 @@
  *
  * $Id: membergroup.cpp,v 1.19 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -27,6 +27,7 @@
 #include "groupdef.h"
 #include "doxygen.h"
 #include "docparser.h"
+#include "marshal.h"
 
 //static QCString idToName(int id)
 //{
@@ -35,11 +36,15 @@
 //  return result;
 //}
 
+MemberGroup::MemberGroup()
+{
+}
+
 MemberGroup::MemberGroup(Definition *parent,
       int id,const char *hdr,const char *d,const char *docFile) 
 {
   //printf("New member group id=%d header=%s desc=%s\n",id,hdr,d);
-  memberList      = new MemberList;
+  memberList      = new MemberList(MemberList::memberGroup);
   grpId           = id;
   grpHeader       = hdr;
   doc             = d;
@@ -47,6 +52,7 @@ MemberGroup::MemberGroup(Definition *parent,
   inSameSection   = TRUE;
   inDeclSection   = 0;
   m_numDecMembers = -1;
+  m_numDocMembers = -1;
   m_parent        = parent;
   m_docFile       = docFile;
   //printf("Member group docs=`%s'\n",doc.data());
@@ -73,6 +79,7 @@ void MemberGroup::insertMember(MemberDef *md)
   else if (inDeclSection==0)
   {
     inDeclSection = md->getSectionList(m_parent);
+    //printf("inDeclSection=%p type=%d\n",inDeclSection,inDeclSection->listType());
   }
   memberList->append(md);
 
@@ -127,6 +134,7 @@ void MemberGroup::addToDeclarationSection()
 {
   if (inDeclSection)
   {
+    //printf("Adding group %p to list %p (type=%d)\n",this,inDeclSection,inDeclSection->listType());
     inDeclSection->addMemberGroup(this);
   }
 }
@@ -141,6 +149,16 @@ int MemberGroup::countDecMembers(/*bool sectionPerType*/)
   return m_numDecMembers;
 }
 
+int MemberGroup::countDocMembers()
+{
+  if (m_numDocMembers==-1)
+  {
+    memberList->countDocMembers();
+    m_numDocMembers = memberList->numDocMembers();
+  }
+  return m_numDocMembers;
+}
+
 void MemberGroup::distributeMemberGroupDocumentation()
 {
   //printf("MemberGroup::distributeMemberGroupDocumentation() %s\n",grpHeader.data());
@@ -233,3 +251,35 @@ void MemberGroup::findSectionsInDocumentation()
   memberList->findSectionsInDocumentation();
 }
 
+void MemberGroup::marshal(StorageIntf *s)
+{
+  marshalMemberList(s,memberList);
+  marshalObjPointer(s,inDeclSection); // reference only
+  marshalInt(s,grpId);
+  marshalQCString(s,grpHeader);
+  marshalQCString(s,fileName);
+  marshalObjPointer(s,scope);
+  marshalQCString(s,doc);
+  marshalBool(s,inSameSection);
+  marshalInt(s,m_numDecMembers);
+  marshalInt(s,m_numDocMembers);
+  marshalObjPointer(s,m_parent);
+  marshalQCString(s,m_docFile);
+}
+
+void MemberGroup::unmarshal(StorageIntf *s)
+{
+  memberList      = unmarshalMemberList(s);
+  inDeclSection   = (MemberList *)unmarshalObjPointer(s); 
+  grpId           = unmarshalInt(s);
+  grpHeader       = unmarshalQCString(s);
+  fileName        = unmarshalQCString(s);
+  scope           = (Definition *)unmarshalObjPointer(s);
+  doc             = unmarshalQCString(s);
+  inSameSection   = unmarshalBool(s);
+  m_numDecMembers = unmarshalInt(s);
+  m_numDocMembers = unmarshalInt(s);
+  m_parent        = (Definition *)unmarshalObjPointer(s);
+  m_docFile       = unmarshalQCString(s);
+}
+
