@@ -51,6 +51,7 @@ NamespaceDef::NamespaceDef(const char *df,int dl,
   memberGroupSDict = new MemberGroupSDict;
   memberGroupSDict->setAutoDelete(TRUE);
   visited=FALSE;
+  m_subGrouping=Config_getBool("SUBGROUPING");
 }
 
 NamespaceDef::~NamespaceDef()
@@ -82,12 +83,15 @@ void NamespaceDef::findSectionsInDocumentation()
   {
     mg->findSectionsInDocumentation();
   }
-  decDefineMembers.findSectionsInDocumentation();
-  decProtoMembers.findSectionsInDocumentation();
-  decTypedefMembers.findSectionsInDocumentation();
-  decEnumMembers.findSectionsInDocumentation();
-  decFuncMembers.findSectionsInDocumentation();
-  decVarMembers.findSectionsInDocumentation();
+  QListIterator<MemberList> mli(m_memberLists);
+  MemberList *ml;
+  for (mli.toFirst();(ml=mli.current());++mli)
+  {
+    if (ml->listType()&MemberList::declarationLists)
+    {
+      ml->findSectionsInDocumentation();
+    }
+  }
 }
 
 void NamespaceDef::insertUsedFile(const char *f)
@@ -139,82 +143,70 @@ void NamespaceDef::insertNamespace(NamespaceDef *nd)
 
 void NamespaceDef::addMembersToMemberGroup()
 {
-  ::addMembersToMemberGroup(&decDefineMembers,memberGroupSDict,this);
-  ::addMembersToMemberGroup(&decProtoMembers,memberGroupSDict,this);
-  ::addMembersToMemberGroup(&decTypedefMembers,memberGroupSDict,this);
-  ::addMembersToMemberGroup(&decEnumMembers,memberGroupSDict,this);
-  ::addMembersToMemberGroup(&decFuncMembers,memberGroupSDict,this);
-  ::addMembersToMemberGroup(&decVarMembers,memberGroupSDict,this);
+  QListIterator<MemberList> mli(m_memberLists);
+  MemberList *ml;
+  for (mli.toFirst();(ml=mli.current());++mli)
+  {
+    if (ml->listType()&MemberList::declarationLists)
+    {
+      ::addMembersToMemberGroup(ml,&memberGroupSDict,this);
+    }
+  }
+
+  // add members inside sections to their groups
+  if (memberGroupSDict)
+  {
+    MemberGroupSDict::Iterator mgli(*memberGroupSDict);
+    MemberGroup *mg;
+    for (;(mg=mgli.current());++mgli)
+    {
+      if (mg->allMembersInSameSection() && m_subGrouping)
+      {
+        //printf("----> addToDeclarationSection(%s)\n",mg->header().data());
+        mg->addToDeclarationSection();
+      }
+    }
+  }
 }
 
 void NamespaceDef::insertMember(MemberDef *md)
 {
-  //memList->append(md);
-  allMemberList.append(md); 
-  static bool sortBriefDocs=Config_getBool("SORT_BRIEF_DOCS");
+  MemberList *allMemberList = getMemberList(MemberList::allMembersList);
+  if (allMemberList==0)
+  {
+    allMemberList = new MemberList(MemberList::allMembersList);
+    m_memberLists.append(allMemberList);
+  }
+  allMemberList->append(md); 
+  ::addNamespaceMemberNameToIndex(md);
+  //static bool sortBriefDocs=Config_getBool("SORT_BRIEF_DOCS");
   switch(md->memberType())
   {
     case MemberDef::Variable:     
-      if (sortBriefDocs)
-        decVarMembers.inSort(md);
-      else
-        decVarMembers.append(md);
-      if (sortBriefDocs)
-        docVarMembers.inSort(md); 
-      else
-        docVarMembers.append(md);
+      addMemberToList(MemberList::decVarMembers,md);
+      addMemberToList(MemberList::docVarMembers,md);
       break;
     case MemberDef::Function: 
-      if (sortBriefDocs)
-        decFuncMembers.inSort(md);
-      else
-        decFuncMembers.append(md);
-      if (sortBriefDocs)
-        docFuncMembers.inSort(md); 
-      else
-        docFuncMembers.append(md);
+      addMemberToList(MemberList::decFuncMembers,md);
+      addMemberToList(MemberList::docFuncMembers,md);
       break;
     case MemberDef::Typedef:      
-      if (sortBriefDocs)
-        decTypedefMembers.inSort(md);
-      else
-        decTypedefMembers.append(md);
-      if (sortBriefDocs)
-        docTypedefMembers.inSort(md); 
-      else
-        docTypedefMembers.append(md);
+      addMemberToList(MemberList::decTypedefMembers,md);
+      addMemberToList(MemberList::docTypedefMembers,md);
       break;
     case MemberDef::Enumeration:  
-      if (sortBriefDocs)
-        decEnumMembers.inSort(md);
-      else
-        decEnumMembers.append(md);
-      if (sortBriefDocs)
-        docEnumMembers.inSort(md); 
-      else
-        docEnumMembers.append(md);
+      addMemberToList(MemberList::decEnumMembers,md);
+      addMemberToList(MemberList::docEnumMembers,md);
       break;
     case MemberDef::EnumValue:    
       break;
     case MemberDef::Prototype:    
-      if (sortBriefDocs)
-        decProtoMembers.inSort(md);
-      else
-        decProtoMembers.append(md);
-      if (sortBriefDocs)
-        docProtoMembers.inSort(md); 
-      else
-        docProtoMembers.append(md);
+      addMemberToList(MemberList::decProtoMembers,md);
+      addMemberToList(MemberList::docProtoMembers,md);
       break;
     case MemberDef::Define:       
-      if (sortBriefDocs)
-        decDefineMembers.inSort(md);
-      else
-        decDefineMembers.append(md);
-      if (sortBriefDocs)
-        docDefineMembers.inSort(md); 
-      else
-        docDefineMembers.append(md);
+      addMemberToList(MemberList::decDefineMembers,md);
+      addMemberToList(MemberList::docDefineMembers,md);
       break;
     default:
       err("NamespaceDef::insertMembers(): "
@@ -223,12 +215,12 @@ void NamespaceDef::insertMember(MemberDef *md)
            md->getClassDef() ? md->getClassDef()->name().data() : "",
            name().data());
   }
-  //addMemberToGroup(md,groupId);
 }
 
 void NamespaceDef::computeAnchors()
 {
-  setAnchors(0,'a',&allMemberList);
+  MemberList *allMemberList = getMemberList(MemberList::allMembersList);
+  if (allMemberList) setAnchors(0,'a',allMemberList);
 }
 
 void NamespaceDef::writeDetailedDocumentation(OutputList &ol)
@@ -340,20 +332,26 @@ void NamespaceDef::writeDocumentation(OutputList &ol)
   namespaceSDict->writeDeclaration(ol,TRUE);
 
   /* write user defined member groups */
-  MemberGroupSDict::Iterator mgli(*memberGroupSDict);
-  MemberGroup *mg;
-  for (;(mg=mgli.current());++mgli)
+  if (memberGroupSDict)
   {
-    mg->writeDeclarations(ol,0,this,0,0);
+    MemberGroupSDict::Iterator mgli(*memberGroupSDict);
+    MemberGroup *mg;
+    for (;(mg=mgli.current());++mgli)
+    {
+      if ((!mg->allMembersInSameSection() || !m_subGrouping) 
+          && mg->header()!="[NOHEADER]")
+      {
+        mg->writeDeclarations(ol,0,this,0,0);
+      }
+    }
   }
 
-  //allMemberList.writeDeclarations(ol,0,this,0,0,0,0);
-  decDefineMembers.writeDeclarations(ol,0,this,0,0,theTranslator->trDefines(),0);
-  decProtoMembers.writeDeclarations(ol,0,this,0,0,theTranslator->trFuncProtos(),0);
-  decTypedefMembers.writeDeclarations(ol,0,this,0,0,theTranslator->trTypedefs(),0);
-  decEnumMembers.writeDeclarations(ol,0,this,0,0,theTranslator->trEnumerations(),0);
-  decFuncMembers.writeDeclarations(ol,0,this,0,0,theTranslator->trFunctions(),0);
-  decVarMembers.writeDeclarations(ol,0,this,0,0,theTranslator->trVariables(),0);
+  writeMemberDeclarations(ol,MemberList::decDefineMembers,theTranslator->trDefines());
+  writeMemberDeclarations(ol,MemberList::decProtoMembers,theTranslator->trFuncProtos());
+  writeMemberDeclarations(ol,MemberList::decTypedefMembers,theTranslator->trTypedefs());
+  writeMemberDeclarations(ol,MemberList::decEnumMembers,theTranslator->trEnumerations());
+  writeMemberDeclarations(ol,MemberList::decFuncMembers,theTranslator->trFunctions());
+  writeMemberDeclarations(ol,MemberList::decVarMembers,theTranslator->trVariables());
   ol.endMemberSections();
   
   if (!Config_getBool("DETAILS_AT_TOP"))
@@ -382,7 +380,8 @@ void NamespaceDef::writeDocumentation(OutputList &ol)
 
   if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
-    allMemberList.sort();
+    MemberList *allMemberList = getMemberList(MemberList::allMembersList);
+    if (allMemberList) allMemberList->sort();
     writeMemberPages(ol);
   }
 }
@@ -394,23 +393,12 @@ void NamespaceDef::writeMemberDocumentation(OutputList &ol)
     ol.disable(OutputGenerator::Html);
   }
   
-  docDefineMembers.writeDocumentation(ol,name(),this,
-                          theTranslator->trDefineDocumentation());
-  
-  docProtoMembers.writeDocumentation(ol,name(),this,
-                          theTranslator->trFunctionPrototypeDocumentation());
-
-  docTypedefMembers.writeDocumentation(ol,name(),this,
-                          theTranslator->trTypedefDocumentation());
-  
-  docEnumMembers.writeDocumentation(ol,name(),this,
-                          theTranslator->trEnumerationTypeDocumentation());
-
-  docFuncMembers.writeDocumentation(ol,name(),this,
-                          theTranslator->trFunctionDocumentation());
-  
-  docVarMembers.writeDocumentation(ol,name(),this,
-                          theTranslator->trVariableDocumentation());
+  writeMemberDocumentation(ol,MemberList::docDefineMembers,theTranslator->trDefineDocumentation());
+  writeMemberDocumentation(ol,MemberList::docProtoMembers,theTranslator->trFunctionPrototypeDocumentation());
+  writeMemberDocumentation(ol,MemberList::docTypedefMembers,theTranslator->trTypedefDocumentation());
+  writeMemberDocumentation(ol,MemberList::docEnumMembers,theTranslator->trEnumerationTypeDocumentation());
+  writeMemberDocumentation(ol,MemberList::docFuncMembers,theTranslator->trFunctionDocumentation());
+  writeMemberDocumentation(ol,MemberList::docVarMembers,theTranslator->trVariableDocumentation());
 
   if (Config_getBool("SEPARATE_MEMBER_PAGES"))
   {
@@ -423,13 +411,15 @@ void NamespaceDef::writeMemberPages(OutputList &ol)
   ol.pushGeneratorState();
   ol.disableAllBut(OutputGenerator::Html);
 
-  docDefineMembers.writeDocumentationPage(ol,name(),this);
-  docProtoMembers.writeDocumentationPage(ol,name(),this);
-  docTypedefMembers.writeDocumentationPage(ol,name(),this);
-  docEnumMembers.writeDocumentationPage(ol,name(),this);
-  docFuncMembers.writeDocumentationPage(ol,name(),this);
-  docVarMembers.writeDocumentationPage(ol,name(),this);
-
+  QListIterator<MemberList> mli(m_memberLists);
+  MemberList *ml;
+  for (mli.toFirst();(ml=mli.current());++mli)
+  {
+    if (ml->listType()&MemberList::documentationLists)
+    {
+      ml->writeDocumentationPage(ol,name(),this);
+    }
+  }
   ol.popGeneratorState();
 }
 
@@ -440,31 +430,35 @@ void NamespaceDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) co
   ol.writeString("      <div class=\"navtab\">\n");
   ol.writeString("        <table>\n");
 
-  MemberListIterator mli(allMemberList);
-  MemberDef *md;
-  for (mli.toFirst();(md=mli.current());++mli)
+  MemberList *allMemberList = getMemberList(MemberList::allMembersList);
+  if (allMemberList)
   {
-    if (md->getNamespaceDef()==this && md->isLinkable())
+    MemberListIterator mli(*allMemberList);
+    MemberDef *md;
+    for (mli.toFirst();(md=mli.current());++mli)
     {
-      ol.writeString("          <tr><td class=\"navtab\">");
-      if (md->isLinkableInProject())
+      if (md->getNamespaceDef()==this && md->isLinkable())
       {
-        if (md==currentMd) // selected item => highlight
+        ol.writeString("          <tr><td class=\"navtab\">");
+        if (md->isLinkableInProject())
         {
-          ol.writeString("<a class=\"qindexHL\" ");
+          if (md==currentMd) // selected item => highlight
+          {
+            ol.writeString("<a class=\"qindexHL\" ");
+          }
+          else
+          {
+            ol.writeString("<a class=\"qindex\" ");
+          }
+          ol.writeString("href=\"");
+          if (createSubDirs) ol.writeString("../../");
+          ol.writeString(md->getOutputFileBase()+Doxygen::htmlFileExtension+"#"+md->anchor());
+          ol.writeString("\">");
+          ol.writeString(md->localName());
+          ol.writeString("</a>");
         }
-        else
-        {
-          ol.writeString("<a class=\"qindex\" ");
-        }
-        ol.writeString("href=\"");
-        if (createSubDirs) ol.writeString("../../");
-        ol.writeString(md->getOutputFileBase()+Doxygen::htmlFileExtension+"#"+md->anchor());
-        ol.writeString("\">");
-        ol.writeString(md->localName());
-        ol.writeString("</a>");
+        ol.writeString("</td></tr>\n");
       }
-      ol.writeString("</td></tr>\n");
     }
   }
 
@@ -474,8 +468,9 @@ void NamespaceDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) co
 
 int NamespaceDef::countMembers()
 {
-  allMemberList.countDocMembers();
-  return allMemberList.numDocMembers()+classSDict->count();
+  MemberList *allMemberList = getMemberList(MemberList::allMembersList);
+  if (allMemberList) allMemberList->countDocMembers();
+  return (allMemberList ? allMemberList->numDocMembers() : 0)+classSDict->count();
 }
 
 void NamespaceDef::addUsingDirective(NamespaceDef *nd)
@@ -488,6 +483,13 @@ void NamespaceDef::addUsingDirective(NamespaceDef *nd)
   {
     usingDirList->append(nd->qualifiedName(),nd);
   }
+  //printf("%p: NamespaceDef::addUsingDirective: %s:%d\n",this,name().data(),usingDirList->count());
+}
+
+NamespaceSDict *NamespaceDef::getUsedNamespaces() const 
+{ 
+  //printf("%p: NamespaceDef::getUsedNamespace: %s:%d\n",this,name().data(),usingDirList?usingDirList->count():0);
+  return usingDirList; 
 }
 
 void NamespaceDef::addUsingDeclaration(Definition *d)
@@ -534,22 +536,28 @@ Definition *NamespaceDef::findInnerCompound(const char *n)
 
 void NamespaceDef::addListReferences()
 {
-  addRefItem(xrefListItems(),
-             theTranslator->trNamespace(TRUE,TRUE),
-             getOutputFileBase(),displayName()
-            );
+  {
+    LockingPtr< QList<ListItemInfo> > xrefItems = xrefListItems();
+    addRefItem(xrefItems.pointer(),
+        theTranslator->trNamespace(TRUE,TRUE),
+        getOutputFileBase(),displayName()
+        );
+  }
   MemberGroupSDict::Iterator mgli(*memberGroupSDict);
   MemberGroup *mg;
   for (;(mg=mgli.current());++mgli)
   {
     mg->addListReferences(this);
   }
-  docDefineMembers.addListReferences(this);
-  docProtoMembers.addListReferences(this);
-  docTypedefMembers.addListReferences(this);
-  docEnumMembers.addListReferences(this);
-  docFuncMembers.addListReferences(this);
-  docVarMembers.addListReferences(this);
+  QListIterator<MemberList> mli(m_memberLists);
+  MemberList *ml;
+  for (mli.toFirst();(ml=mli.current());++mli)
+  {
+    if (ml->listType()&MemberList::documentationLists)
+    {
+      ml->addListReferences(this);
+    }
+  }
 }
 
 QCString NamespaceDef::displayName() const
@@ -669,3 +677,75 @@ void NamespaceSDict::writeDeclaration(OutputList &ol,bool localName)
   ol.endMemberList();
 }
 
+MemberList *NamespaceDef::createMemberList(MemberList::ListType lt)
+{
+  m_memberLists.setAutoDelete(TRUE);
+  QListIterator<MemberList> mli(m_memberLists);
+  MemberList *ml;
+  for (mli.toFirst();(ml=mli.current());++mli)
+  {
+    if (ml->listType()==lt)
+    {
+      return ml;
+    }
+  }
+  // not found, create a new member list
+  ml = new MemberList(lt);
+  m_memberLists.append(ml);
+  return ml;
+}
+
+void NamespaceDef::addMemberToList(MemberList::ListType lt,MemberDef *md)
+{
+  static bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
+  static bool sortMemberDocs = Config_getBool("SORT_MEMBER_DOCS");
+  MemberList *ml = createMemberList(lt);
+  if (((ml->listType()&MemberList::declarationLists) && sortBriefDocs) ||
+      ((ml->listType()&MemberList::documentationLists) && sortMemberDocs)
+     )
+    ml->inSort(md);
+  else
+    ml->append(md);
+  if (ml->listType()&MemberList::declarationLists) md->setSectionList(this,ml);
+}
+
+MemberList *NamespaceDef::getMemberList(MemberList::ListType lt) const
+{
+  NamespaceDef *that = (NamespaceDef*)this;
+  MemberList *ml = that->m_memberLists.first();
+  while (ml)
+  {
+    if (ml->listType()==lt)
+    {
+      return ml;
+    }
+    ml = that->m_memberLists.next();
+  }
+  return 0;
+}
+
+void NamespaceDef::writeMemberDeclarations(OutputList &ol,MemberList::ListType lt,const QCString &title)
+{
+  MemberList * ml = getMemberList(lt);
+  if (ml) ml->writeDeclarations(ol,0,this,0,0,title,0);
+}
+
+void NamespaceDef::writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,const QCString &title)
+{
+  MemberList * ml = getMemberList(lt);
+  if (ml) ml->writeDocumentation(ol,name(),this,title);
+}
+
+
+bool NamespaceDef::isLinkableInProject() const
+{
+  int i = name().findRev("::");
+  if (i==-1) i=0; else i+=2;
+  return !name().isEmpty() && name().at(i)!='@' &&
+    hasDocumentation() && !isReference() && !isHidden();
+}
+
+bool NamespaceDef::isLinkable() const
+{
+  return isLinkableInProject() || isReference();
+}
