@@ -36,6 +36,7 @@ class DotGroupCollaboration;
 class DocNode;
 class MemberDef;
 class GroupDef;
+class Definition;
 
 /*! \brief Output interface for code parser. 
  */
@@ -69,6 +70,8 @@ class CodeOutputInterface
     virtual void startFontClass(const char *) = 0;
     virtual void endFontClass() = 0;
     virtual void writeCodeAnchor(const char *name) = 0;
+    virtual void linkableSymbol(int line,const char *symName,
+                 Definition *symDef,Definition *context) = 0;
 };
 
 /*! \brief Base Interface used for generating output outside of the
@@ -296,8 +299,8 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endIndexKey()   = 0;
     virtual void startIndexValue(bool) = 0;
     virtual void endIndexValue(const char *,bool) = 0;
-    virtual void writeIndexItem(const char *ref,const char *file,
-                                const char *text) = 0;
+    virtual void startIndexItem(const char *ref,const char *file) = 0;
+    virtual void endIndexItem(const char *ref,const char *file) = 0;
     virtual void startGroupHeader() = 0;
     virtual void endGroupHeader() = 0;
     virtual void startMemberSections() = 0;
