@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: pre.h,v 1.10 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -28,5 +28,6 @@ void initPreprocessor();
 void cleanUpPreprocessor();
 void addSearchDir(const char *dir);
 void preprocessFile(const char *fileName,BufStr &output);
+void preFreeScanner();
 
 #endif
