@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -11,11 +11,19 @@
  * input used in their production; they are not affected by this license.
  *
  * Brazilian Portuguese version by
- *   Fabio "FJTC" Jun Takada Chino <chino@icmc.usp.br>
- *      http://www.icmc.sc.usp.br/~chino
- *   Version: 1.3 (2003/05/01)
+ *   Fabio "FJTC" Jun Takada Chino <jun-chino at uol.com.br>
+ *   Version: 1.4.6 (2006/06/26)
  *
  * History:
+ *	 1.4.6
+ *		- trCallerGraph() added.
+ *      - trEnumerationValueDocumentation() added.
+ *   1.4.1
+ *		- Method trOverloadText() added.
+ * 	 1.3.9
+ *		- Updated to Doxygen 1.3.9
+ * 	 1.3.8
+ *		- Updated to Doxygen 1.3.8
  *   1.3.3:
  *      - Updated to Doxygen 1.3.3
  *   1.3.2:
@@ -31,7 +39,7 @@
 #ifndef TRANSLATOR_BR_H
 #define TRANSLATOR_BR_H
 
-class TranslatorBrazilian: public Translator
+class TranslatorBrazilian : public Translator
 {
   public:
 
@@ -175,10 +183,6 @@ class TranslatorBrazilian: public Translator
     virtual QCString trFileList()
     { return "Lista de Arquivos"; }
 
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    virtual QCString trHeaderFiles()
-    { return "Arquivos de Cabealho (Headers)"; }
-
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
@@ -313,10 +317,6 @@ class TranslatorBrazilian: public Translator
       return result;
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    virtual QCString trHeaderFilesDescription()
-    { return "Estes so os arquivos de cabealho que compe a API:"; }
-
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
     { return "Esta  a lista com todos os exemplos:"; }
@@ -329,15 +329,6 @@ class TranslatorBrazilian: public Translator
     virtual QCString trModulesDescription()
     { return "Esta  a lista com todos os mdulos:"; }
 
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given.
-     */
-    virtual QCString trNoDescriptionAvailable()
-    { return "Sem descrio disponvel"; }
-
-    // index titles (the project name is prepended for these)
-
-
     /*! This is used in HTML as the title of index.html. */
     virtual QCString trDocumentation()
     { return "\nDocumentao"; }
@@ -464,7 +455,7 @@ class TranslatorBrazilian: public Translator
      *  documentation blocks for defines
      */
     virtual QCString trDefineDocumentation()
-    { return "Deinies e macros"; }
+    { return "Definies e macros"; }
 
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for function prototypes
@@ -484,12 +475,6 @@ class TranslatorBrazilian: public Translator
     virtual QCString trEnumerationTypeDocumentation()
     { return "Enumeraes"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *  of documentation blocks for enumeration values
-     */
-    virtual QCString trEnumerationValueDocumentation()
-    { return "Valores enumerados"; }
-
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for functions
      */
@@ -544,18 +529,10 @@ class TranslatorBrazilian: public Translator
     virtual QCString trForInternalUseOnly()
     { return "Apenas para uso interno."; }
 
-    /*! this text is generated when the \\reimp command is used. */
-    virtual QCString trReimplementedForInternalReasons()
-    { return "Reimplementado por razes internas. A API no foi modificada."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Aviso"; }
 
-    /*! this text is generated when the \\bug command is used. */
-    virtual QCString trBugsAndLimitations()
-    { return "Problemas e Limitaes"; }
-
     /*! this text is generated when the \\version command is used. */
     virtual QCString trVersion()
     { return "Verso"; }
@@ -830,10 +807,6 @@ class TranslatorBrazilian: public Translator
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    virtual QCString trSources()
-    {
-      return "Cdigos-Fonte";
-    }
     virtual QCString trDefinedAtLineInSourceFile()
     {
       return "Definio na linha @0 do arquivo @1.";
@@ -1136,11 +1109,6 @@ class TranslatorBrazilian: public Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return "Interfaces";
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1173,11 +1141,6 @@ class TranslatorBrazilian: public Translator
     {
       return "Pacotes";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "Pacotes";
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1314,17 +1277,6 @@ class TranslatorBrazilian: public Translator
       return result;
     }
 
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    {
-      QCString result((first_capital ? "Campo" : "campo"));
-      if (!singular)  result+="s";
-      return result;
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names
      *  of the category.
@@ -1535,5 +1487,94 @@ class TranslatorBrazilian: public Translator
     {
       return "Resultados:";
     }
+    
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return  "Cdigo-Fonte de " + filename;
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return "Hierarquia de Diretrios"; }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return "Documentao do Directrio"; }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return "Diretrios"; }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return "Esta Hierarquia de Diretrios est parcialmente ordenada (ordem alfabtica)"; }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    {
+        QCString result = "Referncia do diretrio ";
+     	result += dirName;
+     	return result;
+    }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Diretrio" : "diretrio"));
+      if (!singular) result+="s";
+      return result; 
+    }
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return "Este  um mtodo provido por convenincia. "
+       		"Ele difere do mtodo acima apenas na lista de "
+       		"argumentos que devem ser utilizados.";
+    }    
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used to introduce a caller (or called-by) graph */
+    virtual QCString trCallerGraph()
+    {
+      return "Este  o diagrama de chamadas para esta funo:";
+    }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for enumeration values
+     */
+    virtual QCString trEnumerationValueDocumentation()
+    { return "Documentao da enumerao"; }
+  
 };
 #endif
