@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,7 +18,8 @@
 #ifndef TRANSLATOR_CZ_H
 #define TRANSLATOR_CZ_H
 
-
+// 
+//
 // The first translation from English to Czech was started by
 // Vlastimil Havran (1999--2000). The prototype version of Czech strings 
 // with diacritics was implemented by Petr Prikryl (prikrylp@skil.cz), 
@@ -26,106 +27,48 @@
 //
 // Updates:
 // --------
-// 2000/06/20
-//  - The prototype version of Czech strings with diacritics. The
-//    translation was based on translator.h of Doxygen version
-//    1.1.4 (from scratch).
-//
-// 2000/07/10
-//  - Updated version based on 1.1.5 sources (including important updates
-//    of the up-to-1.1.4 strings). Czech strings in this file were written
-//    in windows-1250 encoding. On-line decoding into iso-8859-2 ensured
-//    via conditional compilation if the sources are compiled under UNIX.
-//
-// 2000/07/19
-//  - Encoding conversion tables moved to the methods that use them.
-//  - Updates for "new since 1.1.5".
-//
-// 2000/08/02 (Petr Prikryl)
-//  - Updated for 1.2.0
-//
-// 2000/08/24
-//  - Changed trTodo() text from "Udelat" to "Planovane upravy"
-//    which seems more appropriate in the document context.
-//  - Typo corrected in trMemberTypedefDocumentation().
-//
-// 2000/08/30
-//  - Macro DECODE replaced by the inline Decode() (proposed by
-//    Boris Bralo <boris.bralo@zg.tel.hr> in translator_hr.h).
-//
-// 2000/08/31
-//  - Methods ISOToWin() and WinToISO() renamed and moved to the
-//    base class (in translator.h) to be shared with the Croatian
-//    translator.
-//
-// 2000/09/06
-//  - Reimplementation of the method trInheritsList() which takes 
-//    into account quantity of base classes.
-//
-// 2000/09/11
-//  - Update for "new since 1.2.1" version. The text of trDCOPMethods()
-//    was translated rather blindly (not knowing what exactly
-//    the DCOP means).
-//    
-// 2000/10/17
-//  - Update for "new since 1.2.2" version. 
-//
-// 2001/01/09
-//  - Update for "new since 1.2.4" version. As I do not use Java,
-//    I tried my best to guess the Czech terminology for the Java.
-//    Let me know if some wording should be changed/improved.
-//         
-// 2001/02/15
-//  - trMore() now returns only "..." (ellipsis).  The Czech replacement
-//    of "(more)" was too much visible.  The previous "(...)" did not 
-//    look well.
-//    
-// 2001/02/26
-//  - Update for "new since 1.2.5" version (trBug(), trBugList()).
-//         
-// 2001/03/12
-//  - Minor correction of comments which copied the same
-//    corrections in translator.h (doubled backslash) just after 
-//    1.2.6 release.
-//    
-// 2001/04/10
-//  - Update for OPTIMIZE_OUTPUT_FOR_C (1.2.6-20010408).
-//  - Removed implementation of latexBabelPackage().
-//  - Removed implementation of trVerbatimText().
-//  
-// 2001/04/20
-//  - Update for "new since 1.2.6-20010422". Experimental version
-//    introducing TranslatorAdapter class and the abstract base
-//    class Translator.  The English translator is now on the same
-//    level as other translators.
-//
-// 2001/05/02
-//  - The Decode() inline identifier changed to decode (i.e. lower
-//    case) to be consistent with HR and RU translator, which also
-//    use the approach.
-//  - Removed the obsolete method trFiles().
-//         
-// 2001/05/18 
-//  - The trRelatedPagesDescription() content updated to fit 
-//    the context better.
-//  - Implemented new method trAuthor(params).
-//  - Removed obsolete methods trAuthor() and trAuthors().
-//
-// 2001/05/25
-//  - Updated misleading information in trLegendDocs().
-//  - The trReimplementedInList() updated to fit the context better.
-//  - The trReimplementedFromList() updated to fit the context better.
-//
+// 2000/06/20 - Prototype: with diacritics; based on ver. 1.1.4 (from scratch).
+// 2000/07/10 - Update to 1.1.5; conditionally decoding to iso-8859-2 for UNIX.
+// 2000/07/19 - Updates for "new since 1.1.5"; encoding conversion separated.
+// 2000/08/02 - Updated for 1.2.0
+// 2000/08/24 - Corrections, updates.
+// 2000/08/30 - Macro DECODE replaced by the inline (thanks to Boris Bralo).
+// 2000/08/31 - ISOToWin() and WinToISO() moved to the base class.
+// 2000/09/06 - Reimplementation of trInheritsList().
+// 2000/09/11 - Update for "new since 1.2.1" version.
+// 2000/10/17 - Update for "new since 1.2.2" version. 
+// 2001/01/09 - Update for "new since 1.2.4" version.
+// 2001/02/15 - trMore() now returns only "..." (ellipsis).
+// 2001/02/26 - Update for "new since 1.2.5" version (trBug(), trBugList()).
+// 2001/03/12 - Minor correction of comments (synchronous with translator.h).
+// 2001/04/10 - Updates (1.2.6-20010408), cleaning.
+// 2001/04/20 - Update for "new since 1.2.6-20010422". Experimental version
+//              introducing TranslatorAdapter class and the abstract base
+//              class Translator.  The English translator is now on the same
+//              level as other translators.
+// 2001/05/02 - Decode() inline changed to decode(); cleaning.
+// 2001/05/18 - Updates, corrections.
+// 2001/05/25 - Corrections.
 // 2001/07/16 - trClassDocumentation() updated as in the English translator.
 // 2001/11/06 - trReferences() implemented.
 // 2002/01/23 - Two new methods "since 1.2.13" implemented.
 // 2002/03/05 - ... forgot to replace TranslatorAdapter... by Translator.
-// 2002/07/08 (my birthday! ;) - The new trRTFTableOfContents() implemented.
+// 2002/07/08 - The new trRTFTableOfContents() implemented. (my birthday! ;) 
 // 2002/07/29 - The new trDeprecatedList() implemented.
 // 2002/10/15 - The new trEvents() and trEventDocumentation() implemented.
 // 2003/04/28 - Five new methods "since 1.3" implemented.
 // 2003/06/10 - Two new methods "since 1.3.1" implemented.
-// 2003/08/13 - Four new "since 1.3.3" implemented. 
+// 2003/08/13 - Four new methods "since 1.3.3" implemented. 
+// 2004/02/26 - trLegendDocs() updated.
+// 2004/02/27 - Text inside the trCallGraph() corrected.
+// 2004/06/16 - The new method "since 1.3.8" implemented. 
+// 2004/09/14 - The new methods "since 1.3.9" implemented. 
+// 2005/02/11 - The "never used" methods removed.
+// 2005/03/08 - Update for "new since 1.4.1" (trOverloadText()) 
+// 2006/05/10 - Update for "new since 1.4.6" -- trCallerGraph(), 
+//              modified trCallGraph() to make the meaning unambiguous
+//              and clear in the Czech language.
+// 2006/06/13 - translation of the trEnumerationValueDocumentation().
 
 // Todo
 // ----
@@ -296,10 +239,6 @@ class TranslatorCzech : public Translator
     virtual QCString trFileList()
     { return decode("Seznam soubor"); }
 
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    virtual QCString trHeaderFiles()
-    { return decode("Seznam hlavikovch soubor"); }
-
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     { 
@@ -442,11 +381,6 @@ class TranslatorCzech : public Translator
       return decode(result);
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    virtual QCString trHeaderFilesDescription()
-    { return decode("Zde naleznete hlavikov soubory, kter tvo "
-             "aplikan programtorsk rozhran (API):"); }
-
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
     { return decode("Zde naleznete seznam vech pklad:"); }
@@ -459,12 +393,6 @@ class TranslatorCzech : public Translator
     virtual QCString trModulesDescription()
     { return decode("Zde naleznete seznam vech modul:"); }
 
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given. 
-     */
-    virtual QCString trNoDescriptionAvailable()
-    { return decode("Popis nen k dispozici"); }
-    
     // index titles (the project name is prepended for these) 
 
 
@@ -614,12 +542,6 @@ class TranslatorCzech : public Translator
     virtual QCString trEnumerationTypeDocumentation()
     { return decode("Dokumentace vtovch typ"); }
 
-    /*! This is used in the documentation of a file/namespace before the list 
-     *  of documentation blocks for enumeration values
-     */
-    virtual QCString trEnumerationValueDocumentation()
-    { return decode("Dokumentace vtovch hodnot"); }
-
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for functions
      */
@@ -674,19 +596,10 @@ class TranslatorCzech : public Translator
     virtual QCString trForInternalUseOnly()
     { return decode("Pouze pro vnitn pouit."); }
 
-    /*! this text is generated when the \\reimp command is used. */
-    virtual QCString trReimplementedForInternalReasons()
-    { return decode("Reimplementovno z internch dvod; "
-                    "aplikan rozhran zachovno."); }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return decode("Pozor"); }
 
-    /*! this text is generated when the \\bug command is used. */
-    virtual QCString trBugsAndLimitations()
-    { return decode("Chyby a omezen"); }
-
     /*! this text is generated when the \\version command is used. */
     virtual QCString trVersion()
     { return decode("Verze"); }
@@ -974,10 +887,6 @@ class TranslatorCzech : public Translator
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    virtual QCString trSources()
-    {
-      return decode("Zdroje");
-    }
     virtual QCString trDefinedAtLineInSourceFile()
     {
       return decode("Definice je uvedena na dku @0 v souboru @1.");
@@ -1184,8 +1093,6 @@ class TranslatorCzech : public Translator
         "/*! Tda, u kter dolo k oezn grafu. Vztah ddinosti "
         "je skryt. */\n"
         "class Truncated : public Invisible { };\n\n"
-        "/* Tda, kter nen dokumentovna komenti programu doxygen. */\n"
-        "class Undocumented { };\n\n"
         "/*! Bzov tda ddn veejn (public inheritance). */\n"
         "class PublicBase : public Truncated { };\n\n"
         "/*! Bzov tda, pouit pro chrnn ddn "
@@ -1194,6 +1101,10 @@ class TranslatorCzech : public Translator
         "/*! Bzov tda, vyuit pro privtn ddn "
         "(private inheritance). */\n"
         "class PrivateBase { };\n\n"
+        "/* Tda, kter nen dokumentovna komenti programu doxygen. */\n"
+        "class Undocumented { };\n\n"
+        "/*! ablona tdy. */\n"
+        "template<class T> class Templ { };\n\n"
         "/*! Tda, kter je vyuvna tdou Inherited. */\n"
         "class Used { };\n\n"
         "/*! Odvozen tda, kter rznm zpsobem dd z vce bzovch "
@@ -1201,7 +1112,8 @@ class TranslatorCzech : public Translator
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
+        "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
         "    Used *m_usedClass;\n"
@@ -1223,7 +1135,7 @@ class TranslatorCzech : public Translator
             "strukturu nebo tdu, pro kterou\n"
             "nejsou zobrazeny vechny vztahy ddinosti nebo obsaen. "
             "Graf je oezn v ppad, kdy jej\n"
-            "nen mon umstit do vymezench hranic.\n"
+            "nen mon umstit do vymezenho prostoru.\n"
         "</ul>\n"
         "ipky (tj. hrany grafu) maj nsledujc vznam:\n"
         "<ul>\n"
@@ -1238,6 +1150,10 @@ class TranslatorCzech : public Translator
             "nebo kdy je pouvna jinou tdou. Je oznaena identifiktorem "
             "jedn nebo vce promnch, pes kter\n"
             "je tda nebo struktura zpstupnna.\n"
+        "<li>lut ipka kreslen rkovan vyjaduje vztah mezi instanc ablony " 
+            "a ablonou tdy, na zklad kter byla\n"
+            "instance ablony vytvoena. V popisu ipky jsou uvedeny  pslun"
+            " parametry ablony.\n"
         "</ul>\n");
         
         return decode(result);
@@ -1292,11 +1208,6 @@ class TranslatorCzech : public Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return decode("Rozhran");
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1323,11 +1234,6 @@ class TranslatorCzech : public Translator
     {
       return decode("Balky");
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return decode("Dokumentace balku");
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1438,17 +1344,6 @@ class TranslatorCzech : public Translator
       return decode(result); 
     }
    
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    { 
-      QCString result((first_capital ? "Polok" : "polok"));
-      result+=(singular ? "a" : "y");
-      return decode(result); 
-    }
-
     /*! ??? Jak to prelozit? Bylo by dobre, kdyby se ozval nekdo,
      * kdo to pouziva.
      */
@@ -1597,7 +1492,7 @@ class TranslatorCzech : public Translator
     /*! Put in front of the call graph for a function. */
     virtual QCString trCallGraph()
     {
-      return decode("Graf voln tto funkce:");
+      return decode("Tato funkce vol...");
     }
    
 //////////////////////////////////////////////////////////////////////////
@@ -1650,6 +1545,103 @@ class TranslatorCzech : public Translator
     {
       return decode("Nalezen slova:");
     }
+    
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return decode("Zdrojov soubor ") + filename;
+    }
+    
+    
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return decode("Hierarchie adres"); }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return decode("Dokumentace k adresm"); }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return decode("Adrese"); }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { 
+        return decode("Nsledujc hierarchie adres je zhruba, "
+                      "ale ne pln, azena podle abecedy:"); 
+    }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { 
+        QCString result = "Reference k adresi "; 
+        result += dirName; 
+        return decode(result); 
+    }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool singular)
+    { 
+        QCString result((first_capital ? "Adres" : "adres"));
+        if ( ! singular) 
+            result += "e";
+        return decode(result); 
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return decode("Jde o petenou (overloaded) metodu, "
+              "kter m usnadnit pouvn. Od ve uveden metody se li "
+              "pouze jinak zadvanmi argumenty.");
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    virtual QCString trCallerGraph()
+    {
+      return decode("Tuto funkci volaj...");
+    }
+
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for enumeration values
+     */
+    virtual QCString trEnumerationValueDocumentation()
+    { 
+      return decode("Dokumentace vtovch hodnot"); 
+    }
 };
 
 #endif // TRANSLATOR_CZ_H
