@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -42,6 +42,10 @@
 */
 class TranslatorEnglish : public Translator
 {
+  protected:
+    friend class TranslatorAdapterBase;
+    virtual ~TranslatorEnglish() {}
+
   public:
 
     // --- Language control methods -------------------
@@ -190,10 +194,6 @@ class TranslatorEnglish : public Translator
     virtual QCString trFileList()
     { return "File List"; }
 
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    virtual QCString trHeaderFiles()
-    { return "Header Files"; }
-
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     { 
@@ -326,10 +326,6 @@ class TranslatorEnglish : public Translator
       return result;
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    virtual QCString trHeaderFilesDescription()
-    { return "Here are the header files that make up the API:"; }
-
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
     { return "Here is a list of all examples:"; }
@@ -342,15 +338,8 @@ class TranslatorEnglish : public Translator
     virtual QCString trModulesDescription()
     { return "Here is a list of all modules:"; }
 
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given. 
-     */
-    virtual QCString trNoDescriptionAvailable()
-    { return "No description available"; }
-    
     // index titles (the project name is prepended for these) 
 
-
     /*! This is used in HTML as the title of index.html. */
     virtual QCString trDocumentation()
     { return "Documentation"; }
@@ -497,12 +486,6 @@ class TranslatorEnglish : public Translator
     virtual QCString trEnumerationTypeDocumentation()
     { return "Enumeration Type Documentation"; }
 
-    /*! This is used in the documentation of a file/namespace before the list 
-     *  of documentation blocks for enumeration values
-     */
-    virtual QCString trEnumerationValueDocumentation()
-    { return "Enumerator Documentation"; }
-
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for functions
      */
@@ -557,18 +540,10 @@ class TranslatorEnglish : public Translator
     virtual QCString trForInternalUseOnly()
     { return "For internal use only."; }
 
-    /*! this text is generated when the \\reimp command is used. */
-    virtual QCString trReimplementedForInternalReasons()
-    { return "Reimplemented for internal reasons; the API is not affected."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Warning"; }
 
-    /*! this text is generated when the \\bug command is used. */
-    virtual QCString trBugsAndLimitations()
-    { return "Bugs and limitations"; }
-
     /*! this text is generated when the \\version command is used. */
     virtual QCString trVersion()
     { return "Version"; }
@@ -843,10 +818,6 @@ class TranslatorEnglish : public Translator
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    virtual QCString trSources()
-    {
-      return "Sources";
-    }
     virtual QCString trDefinedAtLineInSourceFile()
     {
       return "Definition at line @0 of file @1.";
@@ -1153,11 +1124,6 @@ class TranslatorEnglish : public Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return "Interfaces";
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1190,11 +1156,6 @@ class TranslatorEnglish : public Translator
     {
       return "Packages";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "Package Documentation";
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1331,17 +1292,6 @@ class TranslatorEnglish : public Translator
       return result; 
     }
    
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    { 
-      QCString result((first_capital ? "Field" : "field"));
-      if (!singular)  result+="s";
-      return result; 
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
@@ -1615,6 +1565,24 @@ class TranslatorEnglish : public Translator
               "provided for convenience. It differs from the above "
               "function only in what argument(s) it accepts.";
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used to introduce a caller (or called-by) graph */
+    virtual QCString trCallerGraph()
+    {
+      return "Here is the caller graph for this function:";
+    }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for enumeration values
+     */
+    virtual QCString trEnumerationValueDocumentation()
+    { return "Enumerator Documentation"; }
+
+
 };
 
 #endif
