@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2002 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -90,9 +90,6 @@ class TranslatorFinnish : public TranslatorEnglish
 
     QCString idLanguage()
     { return "finnish"; }
-    QCString latexBabelPackage()
-      // returns the name of the package that is included by LaTeX
-    { return "finnish"; }
 
     QCString trRelatedFunctions()
       // used in the compound documentation before a list of related functions.
@@ -124,18 +121,6 @@ class TranslatorFinnish : public TranslatorEnglish
       // header that is put before the list of member attributes.
     { return "Jsen Datan Dokumentaatio"; } // "Member Data Documentation"
 
-    QCString trGeneratedFrom(const char *s,bool single)
-    { // here s is one of " Class", " Struct" or " Union"
-      // single is true implies a single file
-      QCString result=(QCString)"Tmn "+s+ // "The documentation for this"+s+
-                        " dokumentaatio on generoitu ";// " was generated from the following file";
-      if (single) 
-        result+="seuraavasta tiedostosta:";   
-      else 
-        result+="seuraavista tiedostoista:";
-      return result;
-    }
-
     QCString trMore()
       // this is the text of a link put after brief descriptions.
     { return "Lis..."; } // "More..."
@@ -180,11 +165,6 @@ class TranslatorFinnish : public TranslatorEnglish
       // put after an undocumented member in the list of all members
     { return "mritelty"; } // "defined in"
 
-    QCString trVerbatimText(const char *f)
-      // put as in introduction in the verbatim header file of a class.
-      // parameter f is the name of the include file.
-    { return (QCString)"Tm on lyhennetty esitys "+f+" include tiedostosta."; } // "This is the verbatim text of the "+f+" include file."
-
     // quick reference sections
     QCString trModules()
       // This is put above each page as a link to the list of all groups of 
@@ -241,7 +221,7 @@ class TranslatorFinnish : public TranslatorEnglish
       QCString result="Tll on lista kaikista "; // "Here is a list of all "
       if (!extractAll) result+="dokumentoiduista "; // "documented "
       result+="luokan jsenist linkitettyn "; // "class members with links to "
-      if (extractAll) 
+      if (!extractAll) 
         result+="jokaisen jsenen luokkadokumentaatioon:"; // "the class documentation for each member:"
       else 
         result+="luokkaan johon ne kuuluvat:"; // "the classes they belong to:"
@@ -349,10 +329,6 @@ class TranslatorFinnish : public TranslatorEnglish
       // list of (global) variables
     { return "Enumeraation arvot"; } // "Enumeration values"
 
-    QCString trAuthor()
-      // This is used in man pages as the author section.
-    { return "Tekij"; } // "Author"
-
     QCString trDefineDocumentation()
       // This is used in the documentation of a file before the list of
       // documentation blocks for defines
@@ -486,6 +462,8 @@ class TranslatorFinnish : public TranslatorEnglish
         case ClassDef::Struct: result+=" Struct"; break; // "Struct"
         case ClassDef::Union:  result+=" Union"; break; // "Union"
         case ClassDef::Interface: result+=" Interface"; break; // "Interface"
+        case ClassDef::Protocol: result+=" Protocol"; break; // translate me!
+        case ClassDef::Category: result+=" Category"; break; // translate me!
         case ClassDef::Exception: result+=" Exception"; break; // "Interface"
       }
       result+=" Referenssi"; // " Reference"
