@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -65,7 +65,9 @@
 // 2005/03/21
 // - Added strings for 1.4.1
 //
-
+// 2006/06/11
+// - Added strings for 1.4.6
+//
 #ifndef TRANSLATOR_HR_H
 #define TRANSLATOR_HR_H
 
@@ -1254,6 +1256,21 @@ class TranslatorCroatian : public Translator
               "samo po vrsti argumenata koje prihvata.");
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used to introduce a caller (or called-by) graph */
+    virtual QCString trCallerGraph()
+    {
+      return "Ovo je graf funkcija koje pozivaju ovu funkciju:";
+    }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for enumeration values
+     */
+    virtual QCString trEnumerationValueDocumentation()
+    { return "Dokumentacija enumeracija"; }
 };
 
 #endif
