@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2002 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -19,6 +19,22 @@
  *
  * Revision history
  *
+ *  2006/10: made class to derive directly from Translator class (reported in Petr Prikryl October 9 translator report)
+ *  2006/06: updated translation of new items used since version 1.4.6
+ *  2006/05: translated new items used since version 1.4.6
+ *           corrected typo in trPackageMembers method
+ *  2005/03: translated new items used since version 1.4.1
+ *           removed unused methods listed in Petr Prikryl February 28 translator report
+ *  2004/09: translated new items used since version 1.3.9
+ *  2004/06: translated new items used since version 1.3.8
+ *  2003/11: translated new items used since version 1.3.3
+ *  2003/06: translated new items used since version 1.3.1
+ *  2003/04: translated new items used since version 1.3
+ *  2002/11: translated new items used since version 1.2.18
+ *  2002/08: translated new items used since version 1.2.17
+ *  2002/07: translated new items used since version 1.2.16
+ *  2002/06: modified trRelatedPagesDescription() method
+ *           corrected typo in trInclByDepGraph() method
  *  2002/01: translated new items used since version 1.2.13
  *           updated e-mail address
  *  2001/11: corrected the translation fixing the issues reported by the translator.pl script
@@ -53,7 +69,7 @@
  *
  * Il plurale dei termini inglesi non tradotti  stato reso con il singolare
  * della parola inglese secondo una convenzione spesso ritrovata nella documentazione
- * tecnica (ad es "lista dei file" e non "lista dei files")
+ * tecnica (ad es. "lista dei file" e non "lista dei files")
  *
  * Se avete suggerimenti sulla traduzione di alcuni termini o volete segnalare
  * eventuali sviste potete scrivermi all'indirizzo: alessandro@falappa.net
@@ -176,7 +192,7 @@ class TranslatorItalian : public Translator
     // quick reference sections
 
     /*! This is put above each page as a link to the list of all groups of
-     *  compounds or files (see the \group command).
+     *  compounds or files (see the \\group command).
      */
     QCString trModules()
     { return "Moduli"; }
@@ -202,10 +218,6 @@ class TranslatorItalian : public Translator
     QCString trFileList()
     { return "Lista dei file"; }
 
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    QCString trHeaderFiles()
-    { return "Lista dei file header"; }
-
     /*! This is put above each page as a link to all members of compounds. */
     QCString trCompoundMembers()
      {
@@ -323,31 +335,20 @@ class TranslatorItalian : public Translator
       return result;
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    QCString trHeaderFilesDescription()
-    { return "Questi sono gli header file che compongono l'API:"; }
-
     /*! This is an introduction to the page with the list of all examples */
     QCString trExamplesDescription()
     { return "Questa  la lista di tutti gli esempi:"; }
 
     /*! This is an introduction to the page with the list of related pages */
     QCString trRelatedPagesDescription()
-    { return "Questa  la lista di tutte le pagine di documentazione collegate fra loro:"; }
+    { return "Questa  la lista di tutte le pagine di documentazione generale:"; }
 
     /*! This is an introduction to the page with the list of class/file groups */
     QCString trModulesDescription()
     { return "Questa  la lista di tutti i moduli:"; }
 
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given.
-     */
-    QCString trNoDescriptionAvailable()
-    { return "Descrizione non disponibile"; }
-
     // index titles (the project name is prepended for these)
 
-
     /*! This is used in HTML as the title of index.html. */
     QCString trDocumentation()
     { return "Documentazione"; }
@@ -485,12 +486,6 @@ class TranslatorItalian : public Translator
     QCString trEnumerationTypeDocumentation()
     { return "Documentazione dei tipi enumerati"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
-     *  of documentation blocks for enumeration values
-     */
-    QCString trEnumerationValueDocumentation()
-    { return "Documentazione dei valori dei tipi enumerati"; }
-
     /*! This is used in the documentation of a file/namespace before the list
      *  of documentation blocks for functions
      */
@@ -545,18 +540,10 @@ class TranslatorItalian : public Translator
     QCString trForInternalUseOnly()
     { return "Solo per uso interno."; }
 
-    /*! this text is generated when the \\reimp command is used. */
-    QCString trReimplementedForInternalReasons()
-    { return "Reimplementato per motivi interni; l'API non  stata modificata.";}
-
     /*! this text is generated when the \\warning command is used. */
     QCString trWarning()
     { return "Avvertimento"; }
 
-    /*! this text is generated when the \\bug command is used. */
-    QCString trBugsAndLimitations()
-    { return "Bug e limitazioni"; }
-
     /*! this text is generated when the \\version command is used. */
     QCString trVersion()
     { return "Versione"; }
@@ -636,6 +623,8 @@ class TranslatorItalian : public Translator
         case ClassDef::Struct: result+="la struct "; break;
         case ClassDef::Union:  result+="la union "; break;
         case ClassDef::Interface:  result+="l'interfaccia "; break;
+        case ClassDef::Protocol:   result+="protocol "; break; // translate me!
+        case ClassDef::Category:   result+="category "; break; // translate me!
         case ClassDef::Exception:  result+="exception "; break;
       }
       result+=(QCString)clName;
@@ -795,6 +784,8 @@ class TranslatorItalian : public Translator
         case ClassDef::Struct:     result+="struct"; break;
         case ClassDef::Union:      result+="union"; break;
         case ClassDef::Interface:  result+="interfaccia"; break;
+        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
+        case ClassDef::Category:   result+="category"; break; // translate me!
         case ClassDef::Exception:  result+="exception"; break;
       }
       result+="  stata generata a partire ";
@@ -832,10 +823,6 @@ class TranslatorItalian : public Translator
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    QCString trSources()
-    {
-      return "Sorgenti";
-    }
     QCString trDefinedAtLineInSourceFile()
     {
       return "Definizione alla linea @0 del file @1.";
@@ -1011,7 +998,7 @@ class TranslatorItalian : public Translator
     }
     virtual QCString trInclByDepGraph()
     {
-      return "Queato grafo mostra quali file includono direttamente o indirettamente questo file:";
+      return "Questo grafo mostra quali altri file includono direttamente o indirettamente questo file:";
     }
     virtual QCString trSince()
     {
@@ -1128,11 +1115,6 @@ class TranslatorItalian : public Translator
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return "Interfacce";
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1165,11 +1147,6 @@ class TranslatorItalian : public Translator
     {
       return "Package";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "Documentazione dei package";
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1277,17 +1254,6 @@ class TranslatorItalian : public Translator
       return result;
     }
 
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool singular)
-    {
-      QCString result((first_capital ? "Camp" : "camp"));
-      result+=(singular ? "o" : "i");
-      return result;
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names
      *  of the category.
@@ -1342,6 +1308,242 @@ class TranslatorItalian : public Translator
     {
       return "Implementato in "+trWriteList(numEntries)+".";
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.16
+//////////////////////////////////////////////////////////////////////////
+
+    /*! used in RTF documentation as a heading for the Table
+     *  of Contents.
+     */
+    virtual QCString trRTFTableOfContents()
+    {
+      return "Sommario";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.17
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as the header of the list of item that have been
+     *  flagged deprecated
+     */
+    virtual QCString trDeprecatedList()
+    {
+      return "Lista degli elementi deprecati";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.18
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a header for declaration section of the events found in
+     * a C# program
+     */
+    virtual QCString trEvents()
+    {
+      return "Eventi";
+    }
+    /*! Header used for the documentation section of a class' events. */
+    virtual QCString trEventDocumentation()
+    {
+      return "Documentazione degli eventi";
+    }
+
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a heading for a list of Java class types with package scope.
+     */
+    virtual QCString trPackageTypes()
+    {
+      return "Tipi con visibilit di package";
+    }
+    /*! Used as a heading for a list of Java class functions with package
+     * scope.
+     */
+    virtual QCString trPackageMembers()
+    {
+      return "Funzioni con visibilit di package";
+    }
+    /*! Used as a heading for a list of static Java class functions with
+     *  package scope.
+     */
+    virtual QCString trStaticPackageMembers()
+    {
+      return "Funzioni statiche con visibilit di package";
+    }
+    /*! Used as a heading for a list of Java class variables with package
+     * scope.
+     */
+    virtual QCString trPackageAttribs()
+    {
+      return "Attributi con visibilit di package";
+    }
+    /*! Used as a heading for a list of static Java class variables with
+     * package scope.
+     */
+    virtual QCString trStaticPackageAttribs()
+    {
+      return "Attributi statici con visibilit di package";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used in the quick index of a class/file/namespace member list page
+     *  to link to the unfiltered list of all members.
+     */
+    virtual QCString trAll()
+    {
+      return "Tutto";
+    }
+    /*! Put in front of the call graph for a function. */
+    virtual QCString trCallGraph()
+    {
+      return "Questo  il grafo delle chiamate per questa funzione:";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! When the search engine is enabled this text is put in the header
+     *  of each page before the field where one can enter the text to search
+     *  for.
+     */
+    virtual QCString trSearchForIndex()
+    {
+      return "Cerca";
+    }
+    /*! This string is used as the title for the page listing the search
+     *  results.
+     */
+    virtual QCString trSearchResultsTitle()
+    {
+      return "Risultati della ricerca";
+    }
+    /*! This string is put just before listing the search results. The
+     *  text can be different depending on the number of documents found.
+     *  Inside the text you can put the special marker $num to insert
+     *  the number representing the actual number of search results.
+     *  The @a numDocuments parameter can be either 0, 1 or 2, where the
+     *  value 2 represents 2 or more matches. HTML markup is allowed inside
+     *  the returned string.
+     */
+    virtual QCString trSearchResults(int numDocuments)
+    {
+      if (numDocuments==0)
+      {
+        return "Nessun documento soddisfa la tua richiesta.";
+      }
+      else if (numDocuments==1)
+      {
+        return "Trovato <b>1</b> documento rispondente alla tua richiesta.";
+      }
+      else
+      {
+        return "Trovati <b>$num</b> documenti rispondenti alla tua richiesta. "
+               "Le corrispondenze migliori sono in testa.";
+      }
+    }
+    /*! This string is put before the list of matched words, for each search
+     *  result. What follows is the list of words that matched the query.
+     */
+    virtual QCString trSearchMatches()
+    {
+      return "Corrispondenze:";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return " File sorgente " + filename ;
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return "Gerarchia delle directory"; }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return "Documentazione delle directory"; }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return "Directory"; }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return "Questa gerarchia di directory  ordinata "
+        "approssimativamente, ma non completamente, in ordine alfabetico:";
+    }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result="Riferimenti per la directory "; result+=dirName; return result; }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool)
+    {
+      QCString result((first_capital ? "Directory" : "directory"));
+      return result;
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return "Questa  una funzione membro sovraccaricata (overloaded), "
+              "fornita per comodit. Differisce dalla funzione di cui sopra"
+              "unicamente per gli argomenti passati.";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used to introduce a caller (or called-by) graph */
+    virtual QCString trCallerGraph()
+    {
+      return "Questo  il grafo dei chiamanti di questa funzione:";
+    }
+
+    /*! This is used in the documentation of a file/namespace before the list 
+     *  of documentation blocks for enumeration values
+     */
+    virtual QCString trEnumerationValueDocumentation()
+    { return "Documentazione dei tipi enumerati"; }
+
 };
 
 #endif
