@@ -2,7 +2,7 @@
  *
  * $Id: util.h,v 1.49 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -152,6 +152,8 @@ void generateFileRef(OutputDocInterface &od,const char *,
 
 void writePageRef(OutputDocInterface &od,const char *cn,const char *mn);
 
+QCString getCanonicalTemplateSpec(Definition *d,FileDef *fs,const QCString& spec);
+
 bool matchArguments2(Definition *srcScope,FileDef *srcFileScope,ArgumentList *srcAl,
                      Definition *dstScope,FileDef *dstFileScope,ArgumentList *dstAl,
                      bool checkCV
@@ -173,7 +175,8 @@ ClassDef *getResolvedClass(Definition *scope,
                            MemberDef **pTypeDef=0,
                            QCString *pTemplSpec=0,
                            bool mayBeUnlinkable=FALSE,
-                           bool mayBeHidden=FALSE);
+                           bool mayBeHidden=FALSE,
+                           QCString *pResolvedType=0);
 
 NamespaceDef *getResolvedNamespace(const char *key);
 
@@ -218,7 +221,7 @@ void initClassHierarchy(ClassSDict *cl);
 
 bool hasVisibleRoot(BaseClassList *bcl);
 
-int minClassDistance(ClassDef *cd,ClassDef *bcd,int level=0);
+int minClassDistance(const ClassDef *cd,const ClassDef *bcd,int level=0);
 
 QCString convertNameToFile(const char *name,bool allowDots=FALSE);
 
@@ -230,7 +233,9 @@ QCString insertTemplateSpecifierInScope(const QCString &scope,const QCString &te
 
 QCString stripScope(const char *name);
 
-int iSystem(const char *command,const char *args,bool isBatchFile=FALSE);
+int iSystem(const char *command,const char *args,bool commandHasConsole=TRUE);
+
+uint iPid();
 
 QCString convertToHtml(const char *s);
 
@@ -238,9 +243,9 @@ QCString convertToXML(const char *s);
 
 QCString getOverloadDocs();
 
-void addMembersToMemberGroup(MemberList *ml,
-                             MemberGroupSDict *memberGroupSDict,
-                             Definition *context);
+void addMembersToMemberGroup(/* in */     MemberList *ml,
+                             /* in,out */ MemberGroupSDict **ppMemberGroupSDict,
+                             /* in */     Definition *context);
 
 int extractClassNameFromType(const QCString &type,int &pos,
                               QCString &name,QCString &templSpec);
@@ -323,6 +328,9 @@ SrcLangExt getLanguageFromFileName(const QCString fileName);
 
 bool checkIfTypedef(Definition *scope,FileDef *fileScope,const char *n);
 
+ClassDef *newResolveTypedef(FileDef *fileScope,MemberDef *md,
+                            MemberDef **pMemType=0,QCString *pTemplSpec=0,
+                            QCString *pResolvedType=0);
 
 
 #endif
