@@ -39,6 +39,7 @@
 #include <qdir.h>
 #include <qfile.h>
 #include <qtextstream.h>
+#include <qintdict.h>
 
 // no debug info
 #define XML_DB(x) do {} while(0)
@@ -61,6 +62,51 @@ static const char compound_xsd[] =
 
 //------------------
 
+class XmlSectionMapper : public QIntDict<char>
+{
+  public:
+    XmlSectionMapper() : QIntDict<char>(47)
+    {
+      insert(MemberList::pubTypes,"public-type");
+      insert(MemberList::pubMethods,"public-func");
+      insert(MemberList::pubAttribs,"public-attrib");
+      insert(MemberList::pubSlots,"public-slot");
+      insert(MemberList::signals,"signal");
+      insert(MemberList::dcopMethods,"dcop-func");
+      insert(MemberList::properties,"property");
+      insert(MemberList::events,"event");
+      insert(MemberList::pubStaticMethods,"public-static-func");
+      insert(MemberList::pubStaticAttribs,"public-static-attrib");
+      insert(MemberList::proTypes,"protected-type");
+      insert(MemberList::proMethods,"protected-func");
+      insert(MemberList::proAttribs,"protected-attrib");
+      insert(MemberList::proSlots,"protected-slot");
+      insert(MemberList::proStaticMethods,"protected-static-func");
+      insert(MemberList::proStaticAttribs,"protected-static-attrib");
+      insert(MemberList::pacTypes,"package-type");
+      insert(MemberList::pacMethods,"package-func");
+      insert(MemberList::pacAttribs,"package-attrib");
+      insert(MemberList::pacStaticMethods,"package-static-func");
+      insert(MemberList::pacStaticAttribs,"package-static-attrib");
+      insert(MemberList::priTypes,"private-type");
+      insert(MemberList::priMethods,"private-func");
+      insert(MemberList::priAttribs,"private-attrib");
+      insert(MemberList::priSlots,"private-slot");
+      insert(MemberList::priStaticMethods,"private-static-func");
+      insert(MemberList::priStaticAttribs,"private-static-attrib");
+      insert(MemberList::friends,"friend");
+      insert(MemberList::related,"related");
+      insert(MemberList::decDefineMembers,"define");
+      insert(MemberList::decProtoMembers,"prototype");
+      insert(MemberList::decTypedefMembers,"typedef");
+      insert(MemberList::decEnumMembers,"enum");
+      insert(MemberList::decFuncMembers,"func");
+      insert(MemberList::decVarMembers,"var");
+    }
+};
+
+static XmlSectionMapper g_xmlSectionMapper;
+
 
 inline void writeXMLString(QTextStream &t,const char *s)
 {
@@ -346,6 +392,10 @@ class XMLCodeGenerator : public CodeOutputInterface
         if (extRef) m_external=extRef;
       }
     }
+    void linkableSymbol(int, const char *,Definition *,Definition *) 
+    {
+    }
+
     void finish()
     {
       if (m_insideCodeLine) endCodeLine();
@@ -406,9 +456,10 @@ static void writeTemplateArgumentList(ArgumentList *al,
 
 static void writeMemberTemplateLists(MemberDef *md,QTextStream &t)
 {
-  if (md->templateArguments()) // function template prefix
+  LockingPtr<ArgumentList> templMd = md->templateArguments();
+  if (templMd!=0) // function template prefix
   {
-    writeTemplateArgumentList(md->templateArguments(),t,md->getClassDef(),md->getFileDef(),8);
+    writeTemplateArgumentList(templMd.pointer(),t,md->getClassDef(),md->getFileDef(),8);
   }
 }
 
@@ -572,9 +623,9 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
 
   if (isFunc)
   {
-    ArgumentList *al = md->argumentList();
+    LockingPtr<ArgumentList> al = md->argumentList();
     t << " const=\"";
-    if (al && al->constSpecifier)    t << "yes"; else t << "no"; 
+    if (al!=0 && al->constSpecifier)    t << "yes"; else t << "no"; 
     t << "\"";
 
     t << " explicit=\"";
@@ -661,8 +712,8 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
       << rmd->getOutputFileBase() << "_1" << rmd->anchor() << "\">"
       << convertToXML(rmd->name()) << "</reimplements>" << endl;
   }
-  MemberList *rbml = md->reimplementedBy();
-  if (rbml)
+  LockingPtr<MemberList> rbml = md->reimplementedBy();
+  if (rbml!=0)
   {
     MemberListIterator mli(*rbml);
     for (mli.toFirst();(rmd=mli.current());++mli)
@@ -675,9 +726,9 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
 
   if (isFunc) //function
   {
-    ArgumentList *declAl = md->declArgumentList();
-    ArgumentList *defAl = md->argumentList();
-    if (declAl && declAl->count()>0)
+    LockingPtr<ArgumentList> declAl = md->declArgumentList();
+    LockingPtr<ArgumentList> defAl = md->argumentList();
+    if (declAl!=0 && declAl->count()>0)
     {
       ArgumentListIterator declAli(*declAl);
       ArgumentListIterator defAli(*defAl);
@@ -770,9 +821,10 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
   
   if (md->memberType()==MemberDef::Enumeration) // enum
   {
-    if (md->enumFieldList())
+    LockingPtr<MemberList> enumFields = md->enumFieldList();
+    if (enumFields!=0)
     {
-      MemberListIterator emli(*md->enumFieldList());
+      MemberListIterator emli(*enumFields);
       MemberDef *emd;
       for (emli.toFirst();(emd=emli.current());++emli)
       {
@@ -837,18 +889,20 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
   }
 
   //printf("md->getReferencesMembers()=%p\n",md->getReferencesMembers());
-  if (md->getReferencesMembers())
+  LockingPtr<MemberSDict> mdict = md->getReferencesMembers();
+  if (mdict!=0)
   {
-    MemberSDict::Iterator mdi(*md->getReferencesMembers());
+    MemberSDict::Iterator mdi(*mdict);
     MemberDef *rmd;
     for (mdi.toFirst();(rmd=mdi.current());++mdi)
     {
       writeMemberReference(t,def,rmd,"references");
     }
   }
-  if (md->getReferencedByMembers())
+  mdict = md->getReferencedByMembers();
+  if (mdict!=0)
   {
-    MemberSDict::Iterator mdi(*md->getReferencedByMembers());
+    MemberSDict::Iterator mdi(*mdict);
     MemberDef *rmd;
     for (mdi.toFirst();(rmd=mdi.current());++mdi)
     {
@@ -863,6 +917,7 @@ static void generateXMLSection(Definition *d,QTextStream &ti,QTextStream &t,
                       MemberList *ml,const char *kind,const char *header=0,
                       const char *documentation=0)
 {
+  if (ml==0) return;
   MemberListIterator mli(*ml);
   MemberDef *md;
   int count=0;
@@ -903,40 +958,43 @@ static void generateXMLSection(Definition *d,QTextStream &ti,QTextStream &t,
 static void writeListOfAllMembers(ClassDef *cd,QTextStream &t)
 {
   t << "    <listofallmembers>" << endl;
-  MemberNameInfoSDict::Iterator mnii(*cd->memberNameInfoSDict());
-  MemberNameInfo *mni;
-  for (mnii.toFirst();(mni=mnii.current());++mnii)
+  if (cd->memberNameInfoSDict())
   {
-    MemberNameInfoIterator mii(*mni);
-    MemberInfo *mi;
-    for (mii.toFirst();(mi=mii.current());++mii)
+    MemberNameInfoSDict::Iterator mnii(*cd->memberNameInfoSDict());
+    MemberNameInfo *mni;
+    for (mnii.toFirst();(mni=mnii.current());++mnii)
     {
-      MemberDef *md=mi->memberDef;
-      Protection prot = mi->prot;
-      Specifier virt=md->virtualness();
-      t << "      <member refid=\"" << md->getOutputFileBase() << "_1" <<
-        md->anchor() << "\" prot=\"";
-      switch (prot)
+      MemberNameInfoIterator mii(*mni);
+      MemberInfo *mi;
+      for (mii.toFirst();(mi=mii.current());++mii)
       {
-        case Public:    t << "public";    break;
-        case Protected: t << "protected"; break;
-        case Private:   t << "private";   break;
-        case Package:   t << "package";   break;
+        MemberDef *md=mi->memberDef;
+        Protection prot = mi->prot;
+        Specifier virt=md->virtualness();
+        t << "      <member refid=\"" << md->getOutputFileBase() << "_1" <<
+          md->anchor() << "\" prot=\"";
+        switch (prot)
+        {
+          case Public:    t << "public";    break;
+          case Protected: t << "protected"; break;
+          case Private:   t << "private";   break;
+          case Package:   t << "package";   break;
+        }
+        t << "\" virt=\"";
+        switch(virt)
+        {
+          case Normal:  t << "non-virtual";  break;
+          case Virtual: t << "virtual";      break;
+          case Pure:    t << "pure-virtual"; break;
+        }
+        t << "\"";
+        if (!mi->ambiguityResolutionScope.isEmpty())
+        {
+          t << " ambiguityscope=\"" << convertToXML(mi->ambiguityResolutionScope) << "\"";
+        }
+        t << "><scope>" << convertToXML(cd->name()) << "</scope><name>" << 
+          convertToXML(md->name()) << "</name></member>" << endl;
       }
-      t << "\" virt=\"";
-      switch(virt)
-      {
-        case Normal:  t << "non-virtual";  break;
-        case Virtual: t << "virtual";      break;
-        case Pure:    t << "pure-virtual"; break;
-      }
-      t << "\"";
-      if (!mi->ambiguityResolutionScope.isEmpty())
-      {
-        t << " ambiguityscope=\"" << convertToXML(mi->ambiguityResolutionScope) << "\"";
-      }
-      t << "><scope>" << convertToXML(cd->name()) << "</scope><name>" << 
-           convertToXML(md->name()) << "</name></member>" << endl;
     }
   }
   t << "    </listofallmembers>" << endl;
@@ -1098,7 +1156,7 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
   t << "    <compoundname>"; 
   writeXMLString(t,cd->name()); 
   t << "</compoundname>" << endl;
-  if (cd->baseClasses()->count()>0)
+  if (cd->baseClasses())
   {
     BaseClassListIterator bcli(*cd->baseClasses());
     BaseClassDef *bcd;
@@ -1139,7 +1197,7 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
       t  << "</basecompoundref>" << endl;
     }
   }
-  if (cd->subClasses()->count()>0)
+  if (cd->subClasses())
   {
     BaseClassListIterator bcli(*cd->subClasses());
     BaseClassDef *bcd;
@@ -1188,43 +1246,57 @@ static void generateXMLForClass(ClassDef *cd,QTextStream &ti)
   writeInnerClasses(cd->getInnerClasses(),t);
 
   writeTemplateList(cd,t);
-  MemberGroupSDict::Iterator mgli(*cd->memberGroupSDict);
-  MemberGroup *mg;
-  for (;(mg=mgli.current());++mgli)
+  if (cd->getMemberGroupSDict())
   {
-    generateXMLSection(cd,ti,t,mg->members(),"user-defined",mg->header(),
-                       mg->documentation());
+    MemberGroupSDict::Iterator mgli(*cd->getMemberGroupSDict());
+    MemberGroup *mg;
+    for (;(mg=mgli.current());++mgli)
+    {
+      generateXMLSection(cd,ti,t,mg->members(),"user-defined",mg->header(),
+          mg->documentation());
+    }
   }
 
-  generateXMLSection(cd,ti,t,&cd->pubTypes,"public-type");
-  generateXMLSection(cd,ti,t,&cd->pubMethods,"public-func");
-  generateXMLSection(cd,ti,t,&cd->pubAttribs,"public-attrib");
-  generateXMLSection(cd,ti,t,&cd->pubSlots,"public-slot");
-  generateXMLSection(cd,ti,t,&cd->signals,"signal");
-  generateXMLSection(cd,ti,t,&cd->dcopMethods,"dcop-func");
-  generateXMLSection(cd,ti,t,&cd->properties,"property");
-  generateXMLSection(cd,ti,t,&cd->events,"event");
-  generateXMLSection(cd,ti,t,&cd->pubStaticMethods,"public-static-func");
-  generateXMLSection(cd,ti,t,&cd->pubStaticAttribs,"public-static-attrib");
-  generateXMLSection(cd,ti,t,&cd->proTypes,"protected-type");
-  generateXMLSection(cd,ti,t,&cd->proMethods,"protected-func");
-  generateXMLSection(cd,ti,t,&cd->proAttribs,"protected-attrib");
-  generateXMLSection(cd,ti,t,&cd->proSlots,"protected-slot");
-  generateXMLSection(cd,ti,t,&cd->proStaticMethods,"protected-static-func");
-  generateXMLSection(cd,ti,t,&cd->proStaticAttribs,"protected-static-attrib");
-  generateXMLSection(cd,ti,t,&cd->pacTypes,"package-type");
-  generateXMLSection(cd,ti,t,&cd->pacMethods,"package-func");
-  generateXMLSection(cd,ti,t,&cd->pacAttribs,"package-attrib");
-  generateXMLSection(cd,ti,t,&cd->pacStaticMethods,"package-static-func");
-  generateXMLSection(cd,ti,t,&cd->pacStaticAttribs,"package-static-attrib");
-  generateXMLSection(cd,ti,t,&cd->priTypes,"private-type");
-  generateXMLSection(cd,ti,t,&cd->priMethods,"private-func");
-  generateXMLSection(cd,ti,t,&cd->priAttribs,"private-attrib");
-  generateXMLSection(cd,ti,t,&cd->priSlots,"private-slot");
-  generateXMLSection(cd,ti,t,&cd->priStaticMethods,"private-static-func");
-  generateXMLSection(cd,ti,t,&cd->priStaticAttribs,"private-static-attrib");
-  generateXMLSection(cd,ti,t,&cd->friends,"friend");
-  generateXMLSection(cd,ti,t,&cd->related,"related");
+  QListIterator<MemberList> mli(cd->getMemberLists());
+  MemberList *ml;
+  for (mli.toFirst();(ml=mli.current());++mli)
+  {
+    if ((ml->listType()&MemberList::detailedLists)==0)
+    {
+      generateXMLSection(cd,ti,t,ml,g_xmlSectionMapper.find(ml->listType()));
+    }
+  }
+#if 0
+  generateXMLSection(cd,ti,t,cd->pubTypes,"public-type");
+  generateXMLSection(cd,ti,t,cd->pubMethods,"public-func");
+  generateXMLSection(cd,ti,t,cd->pubAttribs,"public-attrib");
+  generateXMLSection(cd,ti,t,cd->pubSlots,"public-slot");
+  generateXMLSection(cd,ti,t,cd->signals,"signal");
+  generateXMLSection(cd,ti,t,cd->dcopMethods,"dcop-func");
+  generateXMLSection(cd,ti,t,cd->properties,"property");
+  generateXMLSection(cd,ti,t,cd->events,"event");
+  generateXMLSection(cd,ti,t,cd->pubStaticMethods,"public-static-func");
+  generateXMLSection(cd,ti,t,cd->pubStaticAttribs,"public-static-attrib");
+  generateXMLSection(cd,ti,t,cd->proTypes,"protected-type");
+  generateXMLSection(cd,ti,t,cd->proMethods,"protected-func");
+  generateXMLSection(cd,ti,t,cd->proAttribs,"protected-attrib");
+  generateXMLSection(cd,ti,t,cd->proSlots,"protected-slot");
+  generateXMLSection(cd,ti,t,cd->proStaticMethods,"protected-static-func");
+  generateXMLSection(cd,ti,t,cd->proStaticAttribs,"protected-static-attrib");
+  generateXMLSection(cd,ti,t,cd->pacTypes,"package-type");
+  generateXMLSection(cd,ti,t,cd->pacMethods,"package-func");
+  generateXMLSection(cd,ti,t,cd->pacAttribs,"package-attrib");
+  generateXMLSection(cd,ti,t,cd->pacStaticMethods,"package-static-func");
+  generateXMLSection(cd,ti,t,cd->pacStaticAttribs,"package-static-attrib");
+  generateXMLSection(cd,ti,t,cd->priTypes,"private-type");
+  generateXMLSection(cd,ti,t,cd->priMethods,"private-func");
+  generateXMLSection(cd,ti,t,cd->priAttribs,"private-attrib");
+  generateXMLSection(cd,ti,t,cd->priSlots,"private-slot");
+  generateXMLSection(cd,ti,t,cd->priStaticMethods,"private-static-func");
+  generateXMLSection(cd,ti,t,cd->priStaticAttribs,"private-static-attrib");
+  generateXMLSection(cd,ti,t,cd->friends,"friend");
+  generateXMLSection(cd,ti,t,cd->related,"related");
+#endif
 
   t << "    <briefdescription>" << endl;
   writeXMLDocBlock(t,cd->briefFile(),cd->briefLine(),cd,0,cd->briefDescription());
@@ -1304,23 +1376,37 @@ static void generateXMLForNamespace(NamespaceDef *nd,QTextStream &ti)
   writeXMLString(t,nd->name());
   t << "</compoundname>" << endl;
 
-  writeInnerClasses(nd->classSDict,t);
-  writeInnerNamespaces(nd->namespaceSDict,t);
+  writeInnerClasses(nd->getClassSDict(),t);
+  writeInnerNamespaces(nd->getNamespaceSDict(),t);
 
-  MemberGroupSDict::Iterator mgli(*nd->memberGroupSDict);
-  MemberGroup *mg;
-  for (;(mg=mgli.current());++mgli)
+  if (nd->getMemberGroupSDict())
   {
-    generateXMLSection(nd,ti,t,mg->members(),"user-defined",mg->header(),
-                       mg->documentation());
+    MemberGroupSDict::Iterator mgli(*nd->getMemberGroupSDict());
+    MemberGroup *mg;
+    for (;(mg=mgli.current());++mgli)
+    {
+      generateXMLSection(nd,ti,t,mg->members(),"user-defined",mg->header(),
+          mg->documentation());
+    }
   }
 
+  QListIterator<MemberList> mli(nd->getMemberLists());
+  MemberList *ml;
+  for (mli.toFirst();(ml=mli.current());++mli)
+  {
+    if ((ml->listType()&MemberList::declarationLists)==0)
+    {
+      generateXMLSection(nd,ti,t,ml,g_xmlSectionMapper.find(ml->listType()));
+    }
+  }
+#if 0
   generateXMLSection(nd,ti,t,&nd->decDefineMembers,"define");
   generateXMLSection(nd,ti,t,&nd->decProtoMembers,"prototype");
   generateXMLSection(nd,ti,t,&nd->decTypedefMembers,"typedef");
   generateXMLSection(nd,ti,t,&nd->decEnumMembers,"enum");
   generateXMLSection(nd,ti,t,&nd->decFuncMembers,"func");
   generateXMLSection(nd,ti,t,&nd->decVarMembers,"var");
+#endif
 
   t << "    <briefdescription>" << endl;
   writeXMLDocBlock(t,nd->briefFile(),nd->briefLine(),nd,0,nd->briefDescription());
@@ -1377,31 +1463,38 @@ static void generateXMLForFile(FileDef *fd,QTextStream &ti)
   writeXMLString(t,fd->name());
   t << "</compoundname>" << endl;
 
-  QListIterator<IncludeInfo> ili1(*fd->includeFileList());
   IncludeInfo *inc;
-  for (ili1.toFirst();(inc=ili1.current());++ili1)
+
+  if (fd->includeFileList())
   {
-    t << "    <includes";
-    if (inc->fileDef && !inc->fileDef->isReference()) // TODO: support external references
+    QListIterator<IncludeInfo> ili1(*fd->includeFileList());
+    for (ili1.toFirst();(inc=ili1.current());++ili1)
     {
-      t << " refid=\"" << inc->fileDef->getOutputFileBase() << "\"";
+      t << "    <includes";
+      if (inc->fileDef && !inc->fileDef->isReference()) // TODO: support external references
+      {
+        t << " refid=\"" << inc->fileDef->getOutputFileBase() << "\"";
+      }
+      t << " local=\"" << (inc->local ? "yes" : "no") << "\">";
+      t << inc->includeName;
+      t << "</includes>" << endl;
     }
-    t << " local=\"" << (inc->local ? "yes" : "no") << "\">";
-    t << inc->includeName;
-    t << "</includes>" << endl;
   }
 
-  QListIterator<IncludeInfo> ili2(*fd->includedByFileList());
-  for (ili2.toFirst();(inc=ili2.current());++ili2)
+  if (fd->includedByFileList())
   {
-    t << "    <includedby";
-    if (inc->fileDef && !inc->fileDef->isReference()) // TODO: support external references
+    QListIterator<IncludeInfo> ili2(*fd->includedByFileList());
+    for (ili2.toFirst();(inc=ili2.current());++ili2)
     {
-      t << " refid=\"" << inc->fileDef->getOutputFileBase() << "\"";
+      t << "    <includedby";
+      if (inc->fileDef && !inc->fileDef->isReference()) // TODO: support external references
+      {
+        t << " refid=\"" << inc->fileDef->getOutputFileBase() << "\"";
+      }
+      t << " local=\"" << (inc->local ? "yes" : "no") << "\">";
+      t << inc->includeName;
+      t << "</includedby>" << endl;
     }
-    t << " local=\"" << (inc->local ? "yes" : "no") << "\">";
-    t << inc->includeName;
-    t << "</includedby>" << endl;
   }
 
   DotInclDepGraph incDepGraph(fd,Config_getInt("MAX_DOT_GRAPH_DEPTH"),FALSE);
@@ -1420,23 +1513,43 @@ static void generateXMLForFile(FileDef *fd,QTextStream &ti)
     t << "    </invincdepgraph>" << endl;
   }
 
-  writeInnerClasses(fd->classSDict,t);
-  writeInnerNamespaces(fd->namespaceSDict,t);
-
-  MemberGroupSDict::Iterator mgli(*fd->memberGroupSDict);
-  MemberGroup *mg;
-  for (;(mg=mgli.current());++mgli)
+  if (fd->getClassSDict())
   {
-    generateXMLSection(fd,ti,t,mg->members(),"user-defined",mg->header(),
-                       mg->documentation());
+    writeInnerClasses(fd->getClassSDict(),t);
+  }
+  if (fd->getNamespaceSDict())
+  {
+    writeInnerNamespaces(fd->getNamespaceSDict(),t);
   }
 
-  generateXMLSection(fd,ti,t,&fd->decDefineMembers,"define");
-  generateXMLSection(fd,ti,t,&fd->decProtoMembers,"prototype");
-  generateXMLSection(fd,ti,t,&fd->decTypedefMembers,"typedef");
-  generateXMLSection(fd,ti,t,&fd->decEnumMembers,"enum");
-  generateXMLSection(fd,ti,t,&fd->decFuncMembers,"func");
-  generateXMLSection(fd,ti,t,&fd->decVarMembers,"var");
+  if (fd->getMemberGroupSDict())
+  {
+    MemberGroupSDict::Iterator mgli(*fd->getMemberGroupSDict());
+    MemberGroup *mg;
+    for (;(mg=mgli.current());++mgli)
+    {
+      generateXMLSection(fd,ti,t,mg->members(),"user-defined",mg->header(),
+          mg->documentation());
+    }
+  }
+
+  QListIterator<MemberList> mli(fd->getMemberLists());
+  MemberList *ml;
+  for (mli.toFirst();(ml=mli.current());++mli)
+  {
+    if ((ml->listType()&MemberList::declarationLists)==0)
+    {
+      generateXMLSection(fd,ti,t,ml,g_xmlSectionMapper.find(ml->listType()));
+    }
+  }
+#if 0
+  generateXMLSection(fd,ti,t,fd->decDefineMembers,"define");
+  generateXMLSection(fd,ti,t,fd->decProtoMembers,"prototype");
+  generateXMLSection(fd,ti,t,fd->decTypedefMembers,"typedef");
+  generateXMLSection(fd,ti,t,fd->decEnumMembers,"enum");
+  generateXMLSection(fd,ti,t,fd->decFuncMembers,"func");
+  generateXMLSection(fd,ti,t,fd->decVarMembers,"var");
+#endif
 
   t << "    <briefdescription>" << endl;
   writeXMLDocBlock(t,fd->briefFile(),fd->briefLine(),fd,0,fd->briefDescription());
@@ -1499,20 +1612,34 @@ static void generateXMLForGroup(GroupDef *gd,QTextStream &ti)
   writeInnerPages(gd->getPages(),t);
   writeInnerGroups(gd->getSubGroups(),t);
 
-  MemberGroupSDict::Iterator mgli(*gd->memberGroupSDict);
-  MemberGroup *mg;
-  for (;(mg=mgli.current());++mgli)
+  if (gd->getMemberGroupSDict())
   {
-    generateXMLSection(gd,ti,t,mg->members(),"user-defined",mg->header(),
-                       mg->documentation());
+    MemberGroupSDict::Iterator mgli(*gd->getMemberGroupSDict());
+    MemberGroup *mg;
+    for (;(mg=mgli.current());++mgli)
+    {
+      generateXMLSection(gd,ti,t,mg->members(),"user-defined",mg->header(),
+          mg->documentation());
+    }
   }
 
+  QListIterator<MemberList> mli(gd->getMemberLists());
+  MemberList *ml;
+  for (mli.toFirst();(ml=mli.current());++mli)
+  {
+    if ((ml->listType()&MemberList::declarationLists)==0)
+    {
+      generateXMLSection(gd,ti,t,ml,g_xmlSectionMapper.find(ml->listType()));
+    }
+  }
+#if 0
   generateXMLSection(gd,ti,t,&gd->decDefineMembers,"define");
   generateXMLSection(gd,ti,t,&gd->decProtoMembers,"prototype");
   generateXMLSection(gd,ti,t,&gd->decTypedefMembers,"typedef");
   generateXMLSection(gd,ti,t,&gd->decEnumMembers,"enum");
   generateXMLSection(gd,ti,t,&gd->decFuncMembers,"func");
   generateXMLSection(gd,ti,t,&gd->decVarMembers,"var");
+#endif
 
   t << "    <briefdescription>" << endl;
   writeXMLDocBlock(t,gd->briefFile(),gd->briefLine(),gd,0,gd->briefDescription());
@@ -1714,7 +1841,7 @@ void generateXML()
   t << "version=\"" << versionString << "\">" << endl;
 
   {
-    ClassSDict::Iterator cli(Doxygen::classSDict);
+    ClassSDict::Iterator cli(*Doxygen::classSDict);
     ClassDef *cd;
     for (cli.toFirst();(cd=cli.current());++cli)
     {
@@ -1731,14 +1858,14 @@ void generateXML()
   //    generateXMLForClass(cd,t);
   //  }
   //}
-  NamespaceSDict::Iterator nli(Doxygen::namespaceSDict);
+  NamespaceSDict::Iterator nli(*Doxygen::namespaceSDict);
   NamespaceDef *nd;
   for (nli.toFirst();(nd=nli.current());++nli)
   {
     msg("Generating XML output for namespace %s\n",nd->name().data());
     generateXMLForNamespace(nd,t);
   }
-  FileNameListIterator fnli(Doxygen::inputNameList);
+  FileNameListIterator fnli(*Doxygen::inputNameList);
   FileName *fn;
   for (;(fn=fnli.current());++fnli)
   {
@@ -1750,7 +1877,7 @@ void generateXML()
       generateXMLForFile(fd,t);
     }
   }
-  GroupSDict::Iterator gli(Doxygen::groupSDict);
+  GroupSDict::Iterator gli(*Doxygen::groupSDict);
   GroupDef *gd;
   for (;(gd=gli.current());++gli)
   {
@@ -1768,7 +1895,7 @@ void generateXML()
   }
   {
     DirDef *dir;
-    DirSDict::Iterator sdi(Doxygen::directories);
+    DirSDict::Iterator sdi(*Doxygen::directories);
     for (sdi.toFirst();(dir=sdi.current());++sdi)
     {
       msg("Generate XML output for dir %s\n",dir->name().data());
